@@ -1,6 +1,7 @@
 import importlib
 import os
-from typing import TYPE_CHECKING, Iterable, Optional, Union, overload
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, Optional, Union, overload
 
 import moto
 
@@ -38,6 +39,7 @@ if TYPE_CHECKING:
     from moto.cognitoidp.models import CognitoIdpBackend
     from moto.comprehend.models import ComprehendBackend
     from moto.config.models import ConfigBackend
+    from moto.connect.models import ConnectBackend
     from moto.connectcampaigns.models import ConnectCampaignServiceBackend
     from moto.core.base_backend import SERVICE_BACKEND, BackendDict
     from moto.databrew.models import DataBrewBackend
@@ -62,7 +64,6 @@ if TYPE_CHECKING:
     from moto.eks.models import EKSBackend
     from moto.elasticache.models import ElastiCacheBackend
     from moto.elasticbeanstalk.models import EBBackend
-    from moto.elastictranscoder.models import ElasticTranscoderBackend
     from moto.elb.models import ELBBackend
     from moto.elbv2.models import ELBv2Backend
     from moto.emr.models import ElasticMapReduceBackend
@@ -113,7 +114,6 @@ if TYPE_CHECKING:
     from moto.personalize.models import PersonalizeBackend
     from moto.pinpoint.models import PinpointBackend
     from moto.polly.models import PollyBackend
-    from moto.qldb.models import QLDBBackend
     from moto.quicksight.models import QuickSightBackend
     from moto.ram.models import ResourceAccessManagerBackend
     from moto.rds.models import RDSBackend
@@ -124,13 +124,13 @@ if TYPE_CHECKING:
     from moto.resiliencehub.models import ResilienceHubBackend
     from moto.resourcegroups.models import ResourceGroupsBackend
     from moto.resourcegroupstaggingapi.models import ResourceGroupsTaggingAPIBackend
-    from moto.robomaker.models import RoboMakerBackend
     from moto.route53.models import Route53Backend
     from moto.route53domains.models import Route53DomainsBackend
     from moto.route53resolver.models import Route53ResolverBackend
     from moto.s3.models import S3Backend
     from moto.s3control.models import S3ControlBackend
     from moto.s3tables.models import S3TablesBackend
+    from moto.s3vectors.models import S3VectorsBackend
     from moto.sagemaker.models import SageMakerModelBackend
     from moto.sagemakermetrics.models import SageMakerMetricsBackend
     from moto.sagemakerruntime.models import SageMakerRuntimeBackend
@@ -231,8 +231,9 @@ SERVICE_NAMES = Union[
     "Literal['cognito-identity']",
     "Literal['cognito-idp']",
     "Literal['comprehend']",
-    "Literal['connectcampaigns']",
     "Literal['config']",
+    "Literal['connect']",
+    "Literal['connectcampaigns']",
     "Literal['databrew']",
     "Literal['datapipeline']",
     "Literal['datasync']",
@@ -253,7 +254,6 @@ SERVICE_NAMES = Union[
     "Literal['eks']",
     "Literal['elasticache']",
     "Literal['elasticbeanstalk']",
-    "Literal['elastictranscoder']",
     "Literal['elb']",
     "Literal['elbv2']",
     "Literal['emr']",
@@ -306,7 +306,6 @@ SERVICE_NAMES = Union[
     "Literal['personalize']",
     "Literal['pinpoint']",
     "Literal['polly']",
-    "Literal['qldb']",
     "Literal['quicksight']",
     "Literal['ram']",
     "Literal['rds']",
@@ -317,7 +316,6 @@ SERVICE_NAMES = Union[
     "Literal['resiliencehub']",
     "Literal['resource-groups']",
     "Literal['resourcegroupstaggingapi']",
-    "Literal['robomaker']",
     "Literal['route53']",
     "Literal['route53resolver']",
     "Literal['route53domains']",
@@ -325,6 +323,7 @@ SERVICE_NAMES = Union[
     "Literal['s3bucket_path']",
     "Literal['s3control']",
     "Literal['s3tables']",
+    "Literal['s3vectors']",
     "Literal['sagemaker']",
     "Literal['sagemaker-metrics']",
     "Literal['sagemaker-runtime']",
@@ -448,12 +447,14 @@ def get_backend(name: "Literal['cognito-idp']") -> "BackendDict[CognitoIdpBacken
 @overload
 def get_backend(name: "Literal['comprehend']") -> "BackendDict[ComprehendBackend]": ...
 @overload
+def get_backend(name: "Literal['config']") -> "BackendDict[ConfigBackend]": ...
+@overload
+def get_backend(name: "Literal['connect']") -> "BackendDict[ConnectBackend]": ...
+@overload
 def get_backend(
     name: "Literal['connectcampaigns']",
 ) -> "BackendDict[ConnectCampaignServiceBackend]": ...
 @overload
-def get_backend(name: "Literal['config']") -> "BackendDict[ConfigBackend]": ...
-@overload
 def get_backend(name: "Literal['databrew']") -> "BackendDict[DataBrewBackend]": ...
 @overload
 def get_backend(
@@ -510,10 +511,6 @@ def get_backend(
 @overload
 def get_backend(name: "Literal['elasticbeanstalk']") -> "BackendDict[EBBackend]": ...
 @overload
-def get_backend(
-    name: "Literal['elastictranscoder']",
-) -> "BackendDict[ElasticTranscoderBackend]": ...
-@overload
 def get_backend(name: "Literal['elb']") -> "BackendDict[ELBBackend]": ...
 @overload
 def get_backend(name: "Literal['elbv2']") -> "BackendDict[ELBv2Backend]": ...
@@ -662,8 +659,6 @@ def get_backend(name: "Literal['pinpoint']") -> "BackendDict[PinpointBackend]":
 @overload
 def get_backend(name: "Literal['polly']") -> "BackendDict[PollyBackend]": ...
 @overload
-def get_backend(name: "Literal['qldb']") -> "BackendDict[QLDBBackend]": ...
-@overload
 def get_backend(name: "Literal['quicksight']") -> "BackendDict[QuickSightBackend]": ...
 @overload
 def get_backend(
@@ -698,8 +693,6 @@ def get_backend(
     name: "Literal['resourcegroupstaggingapi']",
 ) -> "BackendDict[ResourceGroupsTaggingAPIBackend]": ...
 @overload
-def get_backend(name: "Literal['robomaker']") -> "BackendDict[RoboMakerBackend]": ...
-@overload
 def get_backend(name: "Literal['route53']") -> "BackendDict[Route53Backend]": ...
 @overload
 def get_backend(
@@ -716,6 +709,8 @@ def get_backend(name: "Literal['s3bucket_path']") -> "BackendDict[S3Backend]": .
 @overload
 def get_backend(name: "Literal['s3control']") -> "BackendDict[S3ControlBackend]": ...
 @overload
+def get_backend(name: "Literal['s3vectors']") -> "BackendDict[S3VectorsBackend]": ...
+@overload
 def get_backend(
     name: "Literal['sagemaker']",
 ) -> "BackendDict[SageMakerModelBackend]": ...
