@@ -3,12 +3,35 @@ from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
-from moto.core.utils import unix_time
+from moto.core.utils import unix_time, utcnow
 from moto.moto_api._internal import mock_random
 from moto.utilities.tagging_service import TaggingService
 from moto.utilities.utils import get_partition
 
-from .exceptions import AlreadyExistsException, ResourceNotFoundException
+from .exceptions import (
+    AlreadyExistsException,
+    InvalidParameterValueException,
+    InvalidRequestException,
+    ResourceNotFoundException,
+)
+
+
+class ReportPlan(BaseModel):
+    def __init__(
+        self,
+        name: str,
+        report_plan_description: Optional[str],
+        report_delivery_channel: dict[str, Any],
+        report_setting: dict[str, Any],
+        backend: "BackupBackend",
+    ):
+        self.report_plan_name = name
+        self.report_plan_description = report_plan_description
+        self.report_plan_arn = f"arn:{get_partition(backend.region_name)}:backup:{backend.region_name}:{backend.account_id}:report-plan:{name}"
+        self.creation_time = utcnow()
+        self.report_setting = report_setting
+        self.report_delivery_channel = report_delivery_channel
+        self.deployment_status = "COMPLETED"
 
 
 class Plan(BaseModel):
@@ -90,10 +113,11 @@ class Vault(BaseModel):
         self.encryption_key_arn = encryption_key_arn
         self.creator_request_id = creator_request_id
         self.num_of_recovery_points = 0  # start_backup_job not yet supported
-        self.locked = False  # put_backup_vault_lock_configuration
-        self.min_retention_days = 0  # put_backup_vault_lock_configuration
-        self.max_retention_days = 0  # put_backup_vault_lock_configuration
-        self.lock_date = None  # put_backup_vault_lock_configuration
+        self.locked = False
+        self.min_retention_days: Optional[int] = None
+        self.max_retention_days: Optional[int] = None
+        self.lock_date: Optional[float] = None
+        self.changeable_for_days: Optional[int] = None
 
     def to_dict(self) -> dict[str, Any]:
         dct = {
@@ -105,7 +129,6 @@ class Vault(BaseModel):
 
     def to_list_dict(self) -> dict[str, Any]:
         dct = self.to_dict()
-        dct_options: dict[str, Any] = {}
         dct_options = {
             "EncryptionKeyArn": self.encryption_key_arn,
             "CreatorRequestId": self.creator_request_id,
@@ -129,6 +152,7 @@ class BackupBackend(BaseBackend):
 
         self.vaults: dict[str, Vault] = {}
         self.plans: dict[str, Plan] = {}
+        self.report_plans: dict[str, ReportPlan] = {}
         self.tagger = TaggingService()
 
     def create_backup_plan(
@@ -211,6 +235,87 @@ class BackupBackend(BaseBackend):
         self.vaults[backup_vault_name] = vault
         return vault
 
+    def describe_backup_vault(self, backup_vault_name: str) -> Vault:
+        if backup_vault_name not in self.vaults:
+            raise ResourceNotFoundException(backup_vault_name)
+        return self.vaults[backup_vault_name]
+
+    def delete_backup_vault(self, backup_vault_name: str) -> None:
+        self.vaults.pop(backup_vault_name, None)
+
+    def put_backup_vault_lock_configuration(
+        self,
+        backup_vault_name: str,
+        min_retention_days: Optional[int],
+        max_retention_days: Optional[int],
+        changeable_for_days: Optional[int],
+    ) -> None:
+        if backup_vault_name not in self.vaults:
+            raise ResourceNotFoundException(
+                msg=f"Backup vault {backup_vault_name} not found"
+            )
+
+        vault = self.vaults[backup_vault_name]
+
+        if vault.lock_date is not None and unix_time() >= vault.lock_date:
+            raise InvalidRequestException(
+                msg="Vault Lock configuration is immutable and cannot be modified"
+            )
+
+        if min_retention_days is not None and min_retention_days < 1:
+            raise InvalidParameterValueException(
+                msg="MinRetentionDays must be at least 1 day"
+            )
+
+        if max_retention_days is not None and max_retention_days > 36500:
+            raise InvalidParameterValueException(
+                msg="MaxRetentionDays cannot exceed 36500 days"
+            )
+
+        if (
+            min_retention_days is not None
+            and max_retention_days is not None
+            and min_retention_days > max_retention_days
+        ):
+            raise InvalidParameterValueException(
+                msg="MinRetentionDays cannot be greater than MaxRetentionDays"
+            )
+
+        if changeable_for_days is not None and changeable_for_days < 3:
+            raise InvalidParameterValueException(
+                msg="ChangeableForDays must be at least 3 days"
+            )
+
+        vault.locked = True
+        vault.min_retention_days = min_retention_days
+        vault.max_retention_days = max_retention_days
+        vault.changeable_for_days = changeable_for_days
+
+        if changeable_for_days is not None:
+            vault.lock_date = unix_time() + (changeable_for_days * 24 * 60 * 60)
+
+    def delete_backup_vault_lock_configuration(
+        self,
+        backup_vault_name: str,
+    ) -> None:
+        if backup_vault_name not in self.vaults:
+            raise ResourceNotFoundException(
+                msg=f"Backup vault {backup_vault_name} not found"
+            )
+
+        vault = self.vaults[backup_vault_name]
+
+        if vault.lock_date is not None and unix_time() >= vault.lock_date:
+            raise InvalidRequestException(
+                msg="Vault Lock configuration is immutable and cannot be deleted"
+            )
+
+        vault.locked = False
+        vault.min_retention_days = None
+        vault.max_retention_days = None
+        vault.lock_date = None
+        vault.changeable_for_days = None
+
     def list_backup_vaults(self) -> list[Vault]:
         """
         Pagination is not yet implemented
@@ -230,5 +335,41 @@ class BackupBackend(BaseBackend):
     def untag_resource(self, resource_arn: str, tag_key_list: list[str]) -> None:
         self.tagger.untag_resource_using_names(resource_arn, tag_key_list)
 
+    def create_report_plan(
+        self,
+        report_plan_name: str,
+        report_plan_description: Optional[str],
+        report_delivery_channel: dict[str, Any],
+        report_setting: dict[str, Any],
+    ) -> ReportPlan:
+        """
+        The parameters ReportPlanTags and IdempotencyToken are not yet supported
+        """
+        report_plan = ReportPlan(
+            name=report_plan_name,
+            report_setting=report_setting,
+            report_plan_description=report_plan_description,
+            report_delivery_channel=report_delivery_channel,
+            backend=self,
+        )
+        self.report_plans[report_plan_name] = report_plan
+        return report_plan
+
+    def describe_report_plan(self, report_plan_name: str) -> ReportPlan:
+        if report_plan_name not in self.report_plans:
+            raise ResourceNotFoundException(
+                msg=f"Report Plan {report_plan_name} not found"
+            )
+        return self.report_plans[report_plan_name]
+
+    def delete_report_plan(self, report_plan_name: str) -> None:
+        self.report_plans.pop(report_plan_name, None)
+
+    def list_report_plans(self) -> list[ReportPlan]:
+        """
+        Pagination is not yet implemented
+        """
+        return list(self.report_plans.values())
+
 
 backup_backends = BackendDict(BackupBackend, "backup")
