@@ -55,6 +55,7 @@ class BatchSimpleBackend(BatchBackend):
         array_properties: dict[str, Any],
         depends_on: Optional[list[dict[str, str]]] = None,
         container_overrides: Optional[dict[str, Any]] = None,
+        eks_properties_override: Optional[dict[str, Any]] = None,
         timeout: Optional[dict[str, int]] = None,
         parameters: Optional[dict[str, str]] = None,
         tags: Optional[dict[str, str]] = None,
@@ -75,6 +76,7 @@ class BatchSimpleBackend(BatchBackend):
             self,
             log_backend=self.logs_backend,
             container_overrides=container_overrides,
+            eks_properties_override=eks_properties_override,
             depends_on=depends_on,
             all_jobs=self._jobs,
             timeout=timeout,
@@ -94,6 +96,7 @@ class BatchSimpleBackend(BatchBackend):
                     self,
                     log_backend=self.logs_backend,
                     container_overrides=container_overrides,
+                    eks_properties_override=eks_properties_override,
                     depends_on=depends_on,
                     all_jobs=self._jobs,
                     timeout=timeout,
