@@ -248,7 +248,9 @@ class ResponseSerializer:
         response_dict: ResponseDict = {
             "body": "",
             "headers": {},
-            "status_code": self.DEFAULT_RESPONSE_CODE,
+            "status_code": self.operation_model.http.get(
+                "responseCode", self.DEFAULT_RESPONSE_CODE
+            ),
         }
         return response_dict
 
@@ -591,7 +593,10 @@ class BaseXMLSerializer(ResponseSerializer):
         shape: Optional[StructureShape],
         serialized_result: MutableMapping[str, Any],
     ) -> ResponseDict:
-        result_key = f"{self.operation_model.name}Result"
+        if shape and "payload" in shape.serialization:
+            result_key = shape.serialization["payload"]
+        else:
+            result_key = f"{self.operation_model.name}Response"
         result_wrapper = {
             result_key: serialized_result,
         }
@@ -763,6 +768,15 @@ class BaseRestSerializer(ResponseSerializer):
 class RestXMLSerializer(BaseRestSerializer, BaseXMLSerializer):
     DEFAULT_TIMESTAMP_FORMAT = TimestampSerializer.TIMESTAMP_FORMAT_ISO8601
 
+    def _serialize_body(self, body: Mapping[str, Any]) -> str:
+        body_serialized = xmltodict.unparse(
+            body,
+            full_document=True,
+            pretty=self.pretty_print,
+            short_empty_elements=False,
+        )
+        return body_serialized
+
 
 class RestJSONSerializer(BaseRestSerializer, BaseJSONSerializer):
     CONTENT_TYPE = "application/json"
@@ -1187,9 +1201,10 @@ class ShapePrefixAlias(AttributeAliasProvider):
     def has_alias(self, key: str) -> bool:
         shape = self.context.shape
         if shape is not None:
-            if hasattr(shape, "parent"):
+            if hasattr(shape, "parent") and shape.parent.type_name == "structure":
                 if key.lower().startswith(shape.parent.name.lower()):
-                    return True
+                    # Alias is valid if it doesn't conflict with a sibling key.
+                    return self.get_alias(key) not in shape.parent.members
         return False
 
     def get_alias(self, key: str) -> Any:
