@@ -1,7 +1,7 @@
 import copy
 import re
 from collections import OrderedDict
-from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, Optional, Union
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.exceptions import JsonRESTError
@@ -44,26 +44,23 @@ from moto.dynamodb.models.table_export import TableExport
 from moto.dynamodb.models.table_import import TableImport
 from moto.dynamodb.parsing import partiql
 from moto.dynamodb.parsing.executors import UpdateExpressionExecutor
-from moto.dynamodb.parsing.expressions import (  # type: ignore
-    ExpressionAttributeName,
-    UpdateExpressionParser,
-)
+from moto.dynamodb.parsing.expressions import UpdateExpressionParser  # type: ignore
 from moto.dynamodb.parsing.validators import UpdateExpressionValidator
 
 
 class DynamoDBBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.tables: Dict[str, Table] = OrderedDict()
-        self.backups: Dict[str, Backup] = OrderedDict()
-        self.table_imports: Dict[str, TableImport] = {}
-        self.table_exports: Dict[str, TableExport] = {}
-        self.resource_policies: Dict[str, ResourcePolicy] = {}
+        self.tables: dict[str, Table] = OrderedDict()
+        self.backups: dict[str, Backup] = OrderedDict()
+        self.table_imports: dict[str, TableImport] = {}
+        self.table_exports: dict[str, TableExport] = {}
+        self.resource_policies: dict[str, ResourcePolicy] = {}
 
     @staticmethod
     def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
+        service_region: str, zones: list[str]
+    ) -> list[dict[str, str]]:
         """Default VPC endpoint service."""
         # No 'vpce' in the base endpoint DNS name
         return BaseBackend.default_vpc_endpoint_service_factory(
@@ -78,16 +75,17 @@ class DynamoDBBackend(BaseBackend):
     def create_table(
         self,
         name: str,
-        schema: List[Dict[str, str]],
-        throughput: Optional[Dict[str, int]],
-        attr: List[Dict[str, str]],
-        global_indexes: Optional[List[Dict[str, Any]]],
-        indexes: Optional[List[Dict[str, Any]]],
-        streams: Optional[Dict[str, Any]],
+        schema: list[dict[str, str]],
+        throughput: Optional[dict[str, int]],
+        attr: list[dict[str, str]],
+        global_indexes: Optional[list[dict[str, Any]]],
+        indexes: Optional[list[dict[str, Any]]],
+        streams: Optional[dict[str, Any]],
         billing_mode: str,
-        sse_specification: Optional[Dict[str, Any]],
-        tags: List[Dict[str, str]],
-        deletion_protection_enabled: bool,
+        sse_specification: Optional[dict[str, Any]],
+        tags: list[dict[str, str]],
+        deletion_protection_enabled: Optional[bool],
+        warm_throughput: Optional[dict[str, Any]],
     ) -> Table:
         if name in self.tables:
             raise ResourceInUseException(f"Table already exists: {name}")
@@ -105,6 +103,7 @@ class DynamoDBBackend(BaseBackend):
             sse_specification=sse_specification,
             tags=tags,
             deletion_protection_enabled=deletion_protection_enabled,
+            warm_throughput=warm_throughput,
         )
         self.tables[name] = table
         return table
@@ -116,7 +115,7 @@ class DynamoDBBackend(BaseBackend):
                 raise DeletionProtectedException(name)
         return self.tables.pop(table_for_deletion.name)
 
-    def describe_endpoints(self) -> List[Dict[str, Union[int, str]]]:
+    def describe_endpoints(self) -> list[dict[str, Union[int, str]]]:
         return [
             {
                 "Address": f"dynamodb.{self.region_name}.amazonaws.com",
@@ -124,19 +123,19 @@ class DynamoDBBackend(BaseBackend):
             }
         ]
 
-    def tag_resource(self, table_arn: str, tags: List[Dict[str, str]]) -> None:
+    def tag_resource(self, table_arn: str, tags: list[dict[str, str]]) -> None:
         for table in self.tables:
             if self.tables[table].table_arn == table_arn:
                 self.tables[table].tags.extend(tags)
 
-    def untag_resource(self, table_arn: str, tag_keys: List[str]) -> None:
+    def untag_resource(self, table_arn: str, tag_keys: list[str]) -> None:
         for table in self.tables:
             if self.tables[table].table_arn == table_arn:
                 self.tables[table].tags = [
                     tag for tag in self.tables[table].tags if tag["Key"] not in tag_keys
                 ]
 
-    def list_tags_of_resource(self, table_arn: str) -> List[Dict[str, str]]:
+    def list_tags_of_resource(self, table_arn: str) -> list[dict[str, str]]:
         for table in self.tables:
             if self.tables[table].table_arn == table_arn:
                 return self.tables[table].tags
@@ -144,8 +143,8 @@ class DynamoDBBackend(BaseBackend):
 
     def list_tables(
         self, limit: int, exclusive_start_table_name: str
-    ) -> Tuple[List[str], Optional[str]]:
-        all_tables: List[str] = list(self.tables.keys())
+    ) -> tuple[list[str], Optional[str]]:
+        all_tables: list[str] = list(self.tables.keys())
 
         if exclusive_start_table_name:
             try:
@@ -166,7 +165,7 @@ class DynamoDBBackend(BaseBackend):
             return tables, tables[-1]
         return tables, None
 
-    def describe_table(self, name: str) -> Dict[str, Any]:
+    def describe_table(self, name: str) -> dict[str, Any]:
         # Error message is slightly different for this operation
         try:
             table = self.get_table(name)
@@ -177,12 +176,13 @@ class DynamoDBBackend(BaseBackend):
     def update_table(
         self,
         name: str,
-        attr_definitions: List[Dict[str, str]],
-        global_index: List[Dict[str, Any]],
-        throughput: Dict[str, Any],
+        attr_definitions: list[dict[str, str]],
+        global_index: list[dict[str, Any]],
+        throughput: dict[str, Any],
         billing_mode: str,
-        stream_spec: Dict[str, Any],
-        deletion_protection_enabled: bool,
+        stream_spec: dict[str, Any],
+        deletion_protection_enabled: Optional[bool],
+        warm_throughput: Optional[dict[str, Any]],
     ) -> Table:
         table = self.get_table(name)
         if attr_definitions:
@@ -195,12 +195,15 @@ class DynamoDBBackend(BaseBackend):
             table.billing_mode = billing_mode
         if stream_spec:
             self.update_table_streams(table, stream_spec)
-        if deletion_protection_enabled:
+        if deletion_protection_enabled in {True, False}:
             table.deletion_protection_enabled = deletion_protection_enabled
+        if warm_throughput:
+            table.warm_throughput = warm_throughput
+            table.warm_throughput["Status"] = "ACTIVE"
         return table
 
     def update_table_streams(
-        self, table: Table, stream_specification: Dict[str, Any]
+        self, table: Table, stream_specification: dict[str, Any]
     ) -> None:
         if (
             stream_specification.get("StreamEnabled")
@@ -210,9 +213,9 @@ class DynamoDBBackend(BaseBackend):
         table.set_stream_specification(stream_specification)
 
     def update_table_global_indexes(
-        self, table: Table, global_index_updates: List[Dict[str, Any]]
+        self, table: Table, global_index_updates: list[dict[str, Any]]
     ) -> None:
-        gsis_by_name = dict((i.name, i) for i in table.global_indexes)
+        gsis_by_name = {i.name: i for i in table.global_indexes}
         for gsi_update in global_index_updates:
             gsi_to_create = gsi_update.get("Create")
             gsi_to_update = gsi_update.get("Update")
@@ -222,8 +225,9 @@ class DynamoDBBackend(BaseBackend):
                 index_name = gsi_to_delete["IndexName"]
                 if index_name not in gsis_by_name:
                     raise ValueError(
-                        "Global Secondary Index does not exist, but tried to delete: %s"
-                        % gsi_to_delete["IndexName"]
+                        "Global Secondary Index does not exist, but tried to delete: {}".format(
+                            gsi_to_delete["IndexName"]
+                        )
                     )
 
                 del gsis_by_name[index_name]
@@ -232,16 +236,16 @@ class DynamoDBBackend(BaseBackend):
                 index_name = gsi_to_update["IndexName"]
                 if index_name not in gsis_by_name:
                     raise ValueError(
-                        "Global Secondary Index does not exist, but tried to update: %s"
-                        % index_name
+                        f"Global Secondary Index does not exist, but tried to update: {index_name}"
                     )
                 gsis_by_name[index_name].update(gsi_to_update)
 
             if gsi_to_create:
                 if gsi_to_create["IndexName"] in gsis_by_name:
                     raise ValueError(
-                        "Global Secondary Index already exists: %s"
-                        % gsi_to_create["IndexName"]
+                        "Global Secondary Index already exists: {}".format(
+                            gsi_to_create["IndexName"]
+                        )
                     )
 
                 gsis_by_name[gsi_to_create["IndexName"]] = GlobalSecondaryIndex.create(
@@ -253,11 +257,11 @@ class DynamoDBBackend(BaseBackend):
     def put_item(
         self,
         table_name: str,
-        item_attrs: Dict[str, Any],
-        expected: Optional[Dict[str, Any]] = None,
+        item_attrs: dict[str, Any],
+        expected: Optional[dict[str, Any]] = None,
         condition_expression: Optional[str] = None,
-        expression_attribute_names: Optional[Dict[str, Any]] = None,
-        expression_attribute_values: Optional[Dict[str, Any]] = None,
+        expression_attribute_names: Optional[dict[str, Any]] = None,
+        expression_attribute_values: Optional[dict[str, Any]] = None,
         overwrite: bool = False,
         return_values_on_condition_check_failure: Optional[str] = None,
     ) -> Item:
@@ -273,8 +277,8 @@ class DynamoDBBackend(BaseBackend):
         )
 
     def get_table_keys_name(
-        self, table_name: str, keys: Dict[str, Any]
-    ) -> Tuple[Optional[str], Optional[str]]:
+        self, table_name: str, keys: dict[str, Any]
+    ) -> tuple[Optional[str], Optional[str]]:
         """
         Given a set of keys, extracts the key and range key
         """
@@ -296,8 +300,8 @@ class DynamoDBBackend(BaseBackend):
             return potential_hash, potential_range
 
     def get_keys_value(
-        self, table: Table, keys: Dict[str, Any]
-    ) -> Tuple[DynamoType, Optional[DynamoType]]:
+        self, table: Table, keys: dict[str, Any]
+    ) -> tuple[DynamoType, Optional[DynamoType]]:
         if table.hash_key_attr not in keys or (
             table.has_range_key and table.range_key_attr not in keys
         ):
@@ -311,11 +315,11 @@ class DynamoDBBackend(BaseBackend):
 
     def get_schema(
         self, table_name: str, index_name: Optional[str]
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         table = self.get_table(table_name)
         if index_name:
             all_indexes = (table.global_indexes or []) + (table.indexes or [])
-            indexes_by_name = dict((i.name, i) for i in all_indexes)
+            indexes_by_name = {i.name: i for i in all_indexes}
             if index_name not in indexes_by_name:
                 all_index_names = ", ".join(indexes_by_name.keys())
                 raise ResourceNotFoundException(
@@ -327,23 +331,22 @@ class DynamoDBBackend(BaseBackend):
             return table.schema
 
     def get_table(self, table_name: str) -> Table:
-        table = next(
-            (
-                t
-                for t in self.tables.values()
-                if t.name == table_name or t.table_arn == table_name
-            ),
-            None,
-        )
-        if not table:
-            raise ResourceNotFoundException()
-        return table
+        # Find table by name
+        if table := self.tables.get(table_name):
+            return table
+        # Find table by ARN
+        # List of tables might change during this operation, so we have to be defensive about this
+        table_names = list(self.tables.keys())
+        for name in table_names:
+            if (table := self.tables.get(name)) and table.table_arn == table_name:
+                return table
+        raise ResourceNotFoundException()
 
     def get_item(
         self,
         table_name: str,
-        keys: Dict[str, Any],
-        projection_expressions: Optional[List[List[str]]] = None,
+        keys: dict[str, Any],
+        projection_expressions: Optional[list[list[str]]] = None,
     ) -> Optional[Item]:
         table = self.get_table(table_name)
         hash_key, range_key = self.get_keys_value(table, keys)
@@ -352,25 +355,38 @@ class DynamoDBBackend(BaseBackend):
     def query(
         self,
         table_name: str,
-        hash_key_dict: Dict[str, Any],
+        hash_key_dict: Optional[dict[str, Any]],
         range_comparison: Optional[str],
-        range_value_dicts: List[Dict[str, Any]],
+        range_value_dicts: list[dict[str, Any]],
         limit: int,
-        exclusive_start_key: Dict[str, Any],
+        exclusive_start_key: dict[str, Any],
         scan_index_forward: bool,
-        projection_expressions: Optional[List[List[str]]],
+        projection_expressions: Optional[list[list[str]]],
         index_name: Optional[str] = None,
         consistent_read: bool = False,
-        expr_names: Optional[Dict[str, str]] = None,
-        expr_values: Optional[Dict[str, Dict[str, str]]] = None,
+        expr_names: Optional[dict[str, str]] = None,
+        expr_values: Optional[dict[str, dict[str, str]]] = None,
         filter_expression: Optional[str] = None,
+        hash_key_conditions: Optional[list[tuple[str, dict[str, Any]]]] = None,
+        range_key_conditions: Optional[
+            list[tuple[str, str, list[dict[str, Any]]]]
+        ] = None,
         **filter_kwargs: Any,
-    ) -> Tuple[List[Item], int, Optional[Dict[str, Any]]]:
+    ) -> tuple[list[Item], int, Optional[dict[str, Any]]]:
         table = self.get_table(table_name)
 
-        hash_key = DynamoType(hash_key_dict)
+        hash_key = DynamoType(hash_key_dict) if hash_key_dict else None
         range_values = [DynamoType(range_value) for range_value in range_value_dicts]
 
+        # Convert key conditions to DynamoType
+        hash_key_conditions_typed = [
+            (name, DynamoType(value)) for name, value in (hash_key_conditions or [])
+        ]
+        range_key_conditions_typed = [
+            (name, comparison, [DynamoType(v) for v in values])
+            for name, comparison, values in (range_key_conditions or [])
+        ]
+
         filter_expression_op = get_filter_expression(
             filter_expression, expr_names, expr_values
         )
@@ -386,26 +402,28 @@ class DynamoDBBackend(BaseBackend):
             index_name,
             consistent_read,
             filter_expression_op,
+            hash_key_conditions=hash_key_conditions_typed,
+            range_key_conditions=range_key_conditions_typed,
             **filter_kwargs,
         )
 
     def scan(
         self,
         table_name: str,
-        filters: Dict[str, Any],
+        filters: dict[str, Any],
         limit: int,
-        exclusive_start_key: Dict[str, Any],
+        exclusive_start_key: dict[str, Any],
         filter_expression: Optional[str],
-        expr_names: Dict[str, Any],
-        expr_values: Dict[str, Any],
+        expr_names: dict[str, Any],
+        expr_values: dict[str, Any],
         index_name: str,
         consistent_read: bool,
-        projection_expression: Optional[List[List[str]]],
-        segments: Union[Tuple[None, None], Tuple[int, int]],
-    ) -> Tuple[List[Item], int, Optional[Dict[str, Any]]]:
+        projection_expression: Optional[list[list[str]]],
+        segments: Union[tuple[None, None], tuple[int, int]],
+    ) -> tuple[list[Item], int, Optional[dict[str, Any]]]:
         table = self.get_table(table_name)
 
-        scan_filters: Dict[str, Any] = {}
+        scan_filters: dict[str, Any] = {}
         for key, (comparison_operator, comparison_values) in filters.items():
             dynamo_types = [DynamoType(value) for value in comparison_values]
             scan_filters[key] = (comparison_operator, dynamo_types)
@@ -428,12 +446,12 @@ class DynamoDBBackend(BaseBackend):
     def update_item(
         self,
         table_name: str,
-        key: Dict[str, Dict[str, Any]],
+        key: dict[str, dict[str, Any]],
         update_expression: str,
-        expression_attribute_names: Dict[str, Any],
-        expression_attribute_values: Dict[str, Any],
-        attribute_updates: Optional[Dict[str, Any]] = None,
-        expected: Optional[Dict[str, Any]] = None,
+        expression_attribute_names: dict[str, Any],
+        expression_attribute_values: dict[str, Any],
+        attribute_updates: Optional[dict[str, Any]] = None,
+        expected: Optional[dict[str, Any]] = None,
         condition_expression: Optional[str] = None,
         return_values_on_condition_check_failure: Optional[str] = None,
     ) -> Item:
@@ -445,7 +463,6 @@ class DynamoDBBackend(BaseBackend):
             # Parse expression to get validation errors
             update_expression_ast = UpdateExpressionParser.make(update_expression)
             update_expression = re.sub(r"\s*([=\+-])\s*", "\\1", update_expression)
-            update_expression_ast.validate()
 
         if all([table.hash_key_attr in key, table.range_key_attr in key]):
             # Covers cases where table has hash and range keys, ``key`` param
@@ -496,7 +513,7 @@ class DynamoDBBackend(BaseBackend):
                     item=item,
                     table=table,
                 ).validate()
-            data: Dict[str, Any] = {
+            data: dict[str, Any] = {
                 table.hash_key_attr: {hash_value.type: hash_value.value}
             }
             if range_value:
@@ -530,23 +547,6 @@ class DynamoDBBackend(BaseBackend):
             except ItemSizeTooLarge:
                 raise ItemSizeToUpdateTooLarge()
 
-            # Ensure all ExpressionAttributeNames are requested
-            # Either in the Condition, or in the UpdateExpression
-            attr_name_clauses = update_expression_ast.find_clauses(
-                [ExpressionAttributeName]
-            )
-            attr_names_in_expression = [
-                attr.get_attribute_name_placeholder() for attr in attr_name_clauses
-            ]
-            attr_names_in_condition = condition_expression_parser.expr_attr_names_found
-            for attr_name in expression_attribute_names or []:
-                if (
-                    attr_name not in attr_names_in_expression
-                    and attr_name not in attr_names_in_condition
-                ):
-                    raise MockValidationException(
-                        f"Value provided in ExpressionAttributeNames unused in expressions: keys: {{{attr_name}}}"
-                    )
         else:
             item.update_with_attribute_updates(attribute_updates)  # type: ignore
         if table.stream_shard is not None:
@@ -556,9 +556,9 @@ class DynamoDBBackend(BaseBackend):
     def delete_item(
         self,
         table_name: str,
-        key: Dict[str, Any],
-        expression_attribute_names: Optional[Dict[str, Any]] = None,
-        expression_attribute_values: Optional[Dict[str, Any]] = None,
+        key: dict[str, Any],
+        expression_attribute_names: Optional[dict[str, Any]] = None,
+        expression_attribute_values: Optional[dict[str, Any]] = None,
         condition_expression: Optional[str] = None,
         return_values_on_condition_check_failure: Optional[str] = None,
     ) -> Optional[Item]:
@@ -583,7 +583,7 @@ class DynamoDBBackend(BaseBackend):
 
         return table.delete_item(hash_value, range_value)
 
-    def update_time_to_live(self, table_name: str, ttl_spec: Dict[str, Any]) -> None:
+    def update_time_to_live(self, table_name: str, ttl_spec: dict[str, Any]) -> None:
         try:
             table = self.get_table(table_name)
         except ResourceNotFoundException:
@@ -601,7 +601,7 @@ class DynamoDBBackend(BaseBackend):
             table.ttl["TimeToLiveStatus"] = "DISABLED"
         table.ttl["AttributeName"] = ttl_spec["AttributeName"]
 
-    def describe_time_to_live(self, table_name: str) -> Dict[str, Any]:
+    def describe_time_to_live(self, table_name: str) -> dict[str, Any]:
         try:
             table = self.get_table(table_name)
         except ResourceNotFoundException:
@@ -609,78 +609,77 @@ class DynamoDBBackend(BaseBackend):
 
         return table.ttl
 
-    def transact_write_items(self, transact_items: List[Dict[str, Any]]) -> None:
+    def transact_write_items(self, transact_items: list[dict[str, Any]]) -> None:
         if len(transact_items) > 100:
             raise TooManyTransactionsException()
         # Create a backup in case any of the transactions fail
-        original_table_state = copy.deepcopy(self.tables)
-        target_items: Set[Tuple[str, str]] = set()
+        original_table_state: dict[str, Table] = {}
+        for item in transact_items:
+            _, op = next(iter(item.items()))
+            table_name = op.get("TableName")
+            if table_name and table_name in self.tables:
+                original_table_state[table_name] = copy.deepcopy(
+                    self.tables[table_name]
+                )
 
-        def check_unicity(table_name: str, key: Dict[str, Any]) -> None:
+        target_items: set[tuple[str, str]] = set()
+
+        def check_unicity(table_name: str, key: dict[str, Any]) -> None:
             item = (str(table_name), str(key))
             if item in target_items:
                 raise MultipleTransactionsException()
             target_items.add(item)
 
-        errors: List[
-            Union[Tuple[str, str, Dict[str, Any]], Tuple[None, None, None]]
+        errors: list[
+            Union[tuple[str, str, dict[str, Any]], tuple[None, None, None]]
         ] = []  # [(Code, Message, Item), ..]
         for item in transact_items:
-            original_item: Optional[Dict[str, Any]] = None
-            # check transact writes are not performing multiple operations
-            # in the same item
+            original_item: Optional[dict[str, Any]] = None
+            # Check transact writes are not performing multiple operations on the same item
             if len(list(item.keys())) > 1:
                 raise TransactWriteSingleOpException
 
             try:
-                if "ConditionCheck" in item:
-                    item = item["ConditionCheck"]
-                    key = item["Key"]
-                    table_name = item["TableName"]
-                    check_unicity(table_name, key)
-                    condition_expression = item.get("ConditionExpression", None)
-                    expression_attribute_names = item.get(
-                        "ExpressionAttributeNames", None
-                    )
-                    expression_attribute_values = item.get(
-                        "ExpressionAttributeValues", None
-                    )
-                    current = self.get_item(table_name, key)
+                op_type, op = next(iter(item.items()))
+                if op_type not in {"ConditionCheck", "Put", "Delete", "Update"}:
+                    raise ValueError("Unsupported transaction operation")
 
+                table_name = op["TableName"]
+                condition_expression = op.get("ConditionExpression")
+                expression_attribute_names = op.get("ExpressionAttributeNames")
+                expression_attribute_values = op.get("ExpressionAttributeValues")
+                return_values_on_condition_check_failure = op.get(
+                    "ReturnValuesOnConditionCheckFailure"
+                )
+
+                if op_type == "Put":
+                    attrs = op["Item"]
+                    table = self.get_table(table_name)
+                    key = {table.hash_key_attr: attrs[table.hash_key_attr]}
+                    if table.range_key_attr is not None:
+                        key[table.range_key_attr] = attrs[table.range_key_attr]
+                else:
+                    key = op["Key"]
+
+                check_unicity(table_name, key)
+
+                current = self.get_item(table_name, key)
+                if condition_expression is not None:
                     condition_op = get_filter_expression(
                         condition_expression,
                         expression_attribute_names,
                         expression_attribute_values,
                     )
                     if not condition_op.expr(current):
-                        raise ConditionalCheckFailed()
-                elif "Put" in item:
-                    item = item["Put"]
-                    attrs = item["Item"]
-                    table_name = item["TableName"]
-                    table = self.get_table(table_name)
-                    key = {table.hash_key_attr: attrs[table.hash_key_attr]}
-                    if table.range_key_attr is not None:
-                        key[table.range_key_attr] = attrs[table.range_key_attr]
-                    check_unicity(table_name, key)
-                    condition_expression = item.get("ConditionExpression", None)
-                    expression_attribute_names = item.get(
-                        "ExpressionAttributeNames", None
-                    )
-                    expression_attribute_values = item.get(
-                        "ExpressionAttributeValues", None
-                    )
-
-                    return_values_on_condition_check_failure = item.get(
-                        "ReturnValuesOnConditionCheckFailure", None
-                    )
-                    current = self.get_item(table_name, attrs)
-                    if (
-                        return_values_on_condition_check_failure == "ALL_OLD"
-                        and current
-                    ):
-                        original_item = current.to_json()["Attributes"]
+                        if (
+                            return_values_on_condition_check_failure == "ALL_OLD"
+                            and current
+                        ):
+                            original_item = current.to_json()["Attributes"]
+                        raise ConditionalCheckFailed(item=original_item)
 
+                if op_type == "Put":
+                    attrs = op["Item"]
                     self.put_item(
                         table_name,
                         attrs,
@@ -688,18 +687,7 @@ class DynamoDBBackend(BaseBackend):
                         expression_attribute_names=expression_attribute_names,
                         expression_attribute_values=expression_attribute_values,
                     )
-                elif "Delete" in item:
-                    item = item["Delete"]
-                    key = item["Key"]
-                    table_name = item["TableName"]
-                    check_unicity(table_name, key)
-                    condition_expression = item.get("ConditionExpression", None)
-                    expression_attribute_names = item.get(
-                        "ExpressionAttributeNames", None
-                    )
-                    expression_attribute_values = item.get(
-                        "ExpressionAttributeValues", None
-                    )
+                elif op_type == "Delete":
                     self.delete_item(
                         table_name,
                         key,
@@ -707,19 +695,8 @@ class DynamoDBBackend(BaseBackend):
                         expression_attribute_names=expression_attribute_names,
                         expression_attribute_values=expression_attribute_values,
                     )
-                elif "Update" in item:
-                    item = item["Update"]
-                    key = item["Key"]
-                    table_name = item["TableName"]
-                    check_unicity(table_name, key)
-                    update_expression = item["UpdateExpression"]
-                    condition_expression = item.get("ConditionExpression", None)
-                    expression_attribute_names = item.get(
-                        "ExpressionAttributeNames", None
-                    )
-                    expression_attribute_values = item.get(
-                        "ExpressionAttributeValues", None
-                    )
+                elif op_type == "Update":
+                    update_expression = op["UpdateExpression"]
                     self.update_item(
                         table_name,
                         key,
@@ -728,21 +705,25 @@ class DynamoDBBackend(BaseBackend):
                         expression_attribute_names=expression_attribute_names,
                         expression_attribute_values=expression_attribute_values,
                     )
-                else:
-                    raise ValueError
                 errors.append((None, None, None))
-            except MultipleTransactionsException:
+            except (MultipleTransactionsException, MockValidationException):
                 # Rollback to the original state, and reraise the error
-                self.tables = original_table_state
-                raise MultipleTransactionsException()
+                for table_name in original_table_state:
+                    self.tables[table_name] = original_table_state[table_name]
+                raise
+            except ConditionalCheckFailed as e:
+                errors.append(("ConditionalCheckFailed", str(e.message), original_item))  # type: ignore
             except Exception as e:  # noqa: E722 Do not use bare except
-                errors.append((type(e).__name__, e.message, original_item))  # type: ignore
-        if any([code is not None for code, _, _ in errors]):
+                # For other exceptions, capture their details
+                errors.append((type(e).__name__, str(e), original_item))  # type: ignore
+
+        if any(code is not None for code, _, _ in errors):
             # Rollback to the original state, and reraise the errors
-            self.tables = original_table_state
+            for table_name in original_table_state:
+                self.tables[table_name] = original_table_state[table_name]
             raise TransactionCanceledException(errors)
 
-    def describe_continuous_backups(self, table_name: str) -> Dict[str, Any]:
+    def describe_continuous_backups(self, table_name: str) -> dict[str, Any]:
         try:
             table = self.get_table(table_name)
         except ResourceNotFoundException:
@@ -751,8 +732,8 @@ class DynamoDBBackend(BaseBackend):
         return table.continuous_backups
 
     def update_continuous_backups(
-        self, table_name: str, point_in_time_spec: Dict[str, Any]
-    ) -> Dict[str, Any]:
+        self, table_name: str, point_in_time_spec: dict[str, Any]
+    ) -> dict[str, Any]:
         try:
             table = self.get_table(table_name)
         except ResourceNotFoundException:
@@ -782,7 +763,7 @@ class DynamoDBBackend(BaseBackend):
             raise BackupNotFoundException(backup_arn)
         return self.backups[backup_arn]
 
-    def list_backups(self, table_name: str) -> List[Backup]:
+    def list_backups(self, table_name: str) -> list[Backup]:
         backups = list(self.backups.values())
         if table_name is not None:
             backups = [
@@ -870,8 +851,8 @@ class DynamoDBBackend(BaseBackend):
         pass
 
     def execute_statement(
-        self, statement: str, parameters: List[Dict[str, Any]]
-    ) -> List[Dict[str, Any]]:
+        self, statement: str, parameters: list[dict[str, Any]]
+    ) -> list[dict[str, Any]]:
         """
         Pagination is not yet implemented.
 
@@ -879,11 +860,21 @@ class DynamoDBBackend(BaseBackend):
         """
         # We need to execute a statement - but we don't know which table
         # Just pass all tables to PartiQL
-        source_data: Dict[str, str] = dict()
+        source_data: dict[str, list[Any]] = {}
         for table in self.tables.values():
             source_data[table.name] = [  # type: ignore
                 item.to_json()["Attributes"] for item in table.all_items()
             ]
+            for index in table.all_indexes():
+                source_data[f"{table.name}.{index.name}"] = [
+                    item.to_json()["Attributes"]
+                    for item in table.all_items()
+                    # Only add items that contain all index schema attributes
+                    if all(
+                        index_attr["AttributeName"] in item.attrs
+                        for index_attr in index.schema
+                    )
+                ]
 
         return_data, updates_per_table = partiql.query(
             statement, source_data, parameters
@@ -910,8 +901,8 @@ class DynamoDBBackend(BaseBackend):
         return return_data
 
     def execute_transaction(
-        self, statements: List[Dict[str, Any]]
-    ) -> List[Dict[str, Any]]:
+        self, statements: list[dict[str, Any]]
+    ) -> list[dict[str, Any]]:
         """
         Please see the documentation for `execute_statement` to see the limitations of what is supported.
         """
@@ -924,8 +915,8 @@ class DynamoDBBackend(BaseBackend):
         return responses
 
     def batch_execute_statement(
-        self, statements: List[Dict[str, Any]]
-    ) -> List[Dict[str, Any]]:
+        self, statements: list[dict[str, Any]]
+    ) -> list[dict[str, Any]]:
         """
         Please see the documentation for `execute_statement` to see the limitations of what is supported.
         """
@@ -972,15 +963,15 @@ class DynamoDBBackend(BaseBackend):
 
     def import_table(
         self,
-        s3_source: Dict[str, str],
+        s3_source: dict[str, str],
         input_format: Optional[str],
         compression_type: Optional[str],
         table_name: str,
         billing_mode: str,
-        throughput: Optional[Dict[str, int]],
-        key_schema: List[Dict[str, str]],
-        global_indexes: Optional[List[Dict[str, Any]]],
-        attrs: List[Dict[str, str]],
+        throughput: Optional[dict[str, int]],
+        key_schema: list[dict[str, str]],
+        global_indexes: Optional[list[dict[str, Any]]],
+        attrs: list[dict[str, str]],
     ) -> TableImport:
         """
         Only InputFormat=DYNAMODB_JSON is supported so far.
@@ -1047,7 +1038,7 @@ class DynamoDBBackend(BaseBackend):
     def describe_export(self, export_arn: str) -> TableExport:
         return self.table_exports[export_arn]
 
-    def list_exports(self, table_arn: str) -> List[TableExport]:
+    def list_exports(self, table_arn: str) -> list[TableExport]:
         exports = []
         for export_arn in self.table_exports:
             if self.table_exports[export_arn].table.table_arn == table_arn:
