@@ -1,7 +1,7 @@
 import base64
 import copy
 from decimal import Decimal
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Optional, Union, cast
 
 from boto3.dynamodb.types import TypeDeserializer, TypeSerializer
 from botocore.utils import merge_dicts
@@ -56,12 +56,12 @@ class DDBTypeConversion:
         return cls._human_type_mapping.get(abbreviated_type, abbreviated_type)
 
 
-class DynamoType(object):
+class DynamoType:
     """
     http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/DataModel.html#DataModelDataTypes
     """
 
-    def __init__(self, type_as_dict: Union["DynamoType", Dict[str, Any]]):
+    def __init__(self, type_as_dict: Union["DynamoType", dict[str, Any]]):
         if type(type_as_dict) is DynamoType:
             self.type: str = type_as_dict.type
             self.value: Any = type_as_dict.value
@@ -71,7 +71,7 @@ class DynamoType(object):
         if self.is_list():
             self.value = [DynamoType(val) for val in self.value]
         elif self.is_map():
-            self.value = dict((k, DynamoType(v)) for k, v in self.value.items())
+            self.value = {k: DynamoType(v) for k, v in self.value.items()}
 
     def __hash__(self) -> int:
         return hash((self.type, self.value))
@@ -97,6 +97,25 @@ class DynamoType(object):
     def __repr__(self) -> str:
         return f"DynamoType: {self.to_json()}"
 
+    def __deepcopy__(self, memo: dict[int, Any]) -> "DynamoType":
+        """Custom deepcopy that bypasses the expensive default pickle-based
+        __reduce_ex__ protocol. Safe for DynamoDB AttributeValue trees,
+        which are acyclic."""
+        if id(self) in memo:  # pragma: no cover
+            return memo[id(self)]  # Circular refs can't occur in DynamoDB data
+        result = self.__class__.__new__(self.__class__)
+        memo[id(self)] = result
+        result.type = self.type
+        if self.is_list():
+            result.value = [copy.deepcopy(v, memo) for v in self.value]
+        elif self.is_map():
+            result.value = {k: copy.deepcopy(v, memo) for k, v in self.value.items()}
+        elif self.is_set():
+            result.value = list(self.value)
+        else:
+            result.value = self.value
+        return result
+
     def __add__(self, other: "DynamoType") -> "DynamoType":
         if self.type != other.type:
             raise TypeError("Different types of operandi is not allowed.")
@@ -163,11 +182,13 @@ class DynamoType(object):
                 return float(self.value)
         elif self.is_set():
             sub_type = self.type[0]
-            return set([DynamoType({sub_type: v}).cast_value for v in self.value])
+            return {DynamoType({sub_type: v}).cast_value for v in self.value}
         elif self.is_list():
             return [DynamoType(v).cast_value for v in self.value]
         elif self.is_map():
-            return dict([(k, DynamoType(v).cast_value) for k, v in self.value.items()])
+            return {k: DynamoType(v).cast_value for k, v in self.value.items()}
+        elif self.is_null():
+            return None
         else:
             return self.value
 
@@ -206,7 +227,7 @@ class DynamoType(object):
             value_size = bytesize(self.value)
         return value_size
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         # Returns a regular JSON object where the value can still be/contain a DynamoType
         if self.is_binary() and isinstance(self.value, bytes):
             # Binary data cannot be represented in JSON
@@ -214,7 +235,7 @@ class DynamoType(object):
             return {self.type: base64.b64encode(self.value).decode("utf-8")}
         return {self.type: self.value}
 
-    def to_regular_json(self) -> Dict[str, Any]:
+    def to_regular_json(self) -> dict[str, Any]:
         # Returns a regular JSON object in full
         value = copy.deepcopy(self.value)
         if isinstance(value, dict):
@@ -233,7 +254,7 @@ class DynamoType(object):
             value = base64.b64decode(value)
         return {self.type: value}
 
-    def compare(self, range_comparison: str, range_objs: List[Any]) -> bool:
+    def compare(self, range_comparison: str, range_objs: list[Any]) -> bool:
         """
         Compares this type against comparison filters
         """
@@ -258,6 +279,9 @@ class DynamoType(object):
     def is_binary(self) -> bool:
         return self.type == DDBType.BINARY
 
+    def is_null(self) -> bool:
+        return self.type == DDBType.NULL
+
     def same_type(self, other: "DynamoType") -> bool:
         return self.type == other.type
 
@@ -270,7 +294,7 @@ class DynamoType(object):
 
 # https://github.com/getmoto/moto/issues/1874
 # Ensure that the total size of an item does not exceed 400kb
-class LimitedSizeDict(Dict[str, Any]):
+class LimitedSizeDict(dict[str, Any]):
     def __init__(self, *args: Any, **kwargs: Any):
         self.update(*args, **kwargs)
 
@@ -297,7 +321,7 @@ class Item(BaseModel):
         self,
         hash_key: DynamoType,
         range_key: Optional[DynamoType],
-        attrs: Dict[str, Any],
+        attrs: dict[str, Any],
     ):
         self.hash_key = hash_key
         self.range_key = range_key
@@ -318,11 +342,31 @@ class Item(BaseModel):
     def __repr__(self) -> str:
         return f"Item: {self.to_json()}"
 
+    def __deepcopy__(self, memo: dict[int, Any]) -> "Item":
+        """Custom deepcopy that bypasses the expensive default pickle-based
+        __reduce_ex__ protocol, and skips LimitedSizeDict size validation
+        during copy (the source item already passed validation on write)."""
+        if id(self) in memo:  # pragma: no cover
+            return memo[id(self)]  # Circular refs can't occur in DynamoDB data
+        result = cast(Item, self.__class__.__new__(self.__class__))
+        memo[id(self)] = result
+        result.hash_key = copy.deepcopy(self.hash_key, memo)
+        result.range_key = copy.deepcopy(self.range_key, memo)
+        # Bypass LimitedSizeDict.__setitem__ which runs O(n) size validation on
+        # every insert. The source item already passed validation, so re-checking
+        # during copy is unnecessary and would make the overall copy O(n²).
+        attrs_copy = LimitedSizeDict.__new__(LimitedSizeDict)
+        dict.__init__(attrs_copy)
+        for key, value in self.attrs.items():
+            dict.__setitem__(attrs_copy, key, copy.deepcopy(value, memo))
+        result.attrs = attrs_copy
+        return result
+
     def size(self) -> int:
         return sum(bytesize(key) + value.size() for key, value in self.attrs.items())
 
-    def to_json(self, root_attr_name: str = "Attributes") -> Dict[str, Any]:
-        attributes: Dict[str, Any] = {}
+    def to_json(self, root_attr_name: str = "Attributes") -> dict[str, Any]:
+        attributes: dict[str, Any] = {}
         for attribute_key, attribute in self.attrs.items():
             if isinstance(attribute.value, dict):
                 attr_dict_value = {
@@ -341,15 +385,15 @@ class Item(BaseModel):
 
         return {root_attr_name: attributes}
 
-    def to_regular_json(self) -> Dict[str, Any]:
+    def to_regular_json(self) -> dict[str, Any]:
         attributes = {}
         for key, attribute in self.attrs.items():
             attributes[key] = deserializer.deserialize(attribute.to_regular_json())
         return attributes
 
     def describe_attrs(
-        self, attributes: Optional[Dict[str, Any]] = None
-    ) -> Dict[str, Dict[str, Any]]:
+        self, attributes: Optional[dict[str, Any]] = None
+    ) -> dict[str, dict[str, Any]]:
         if attributes:
             included = {}
             for key, value in self.attrs.items():
@@ -360,7 +404,7 @@ class Item(BaseModel):
         return {"Item": included}
 
     def validate_no_empty_key_values(
-        self, attribute_updates: Dict[str, Any], key_attributes: List[str]
+        self, attribute_updates: dict[str, Any], key_attributes: list[str]
     ) -> None:
         for attribute_name, update_action in attribute_updates.items():
             action = update_action.get("Action") or "PUT"  # PUT is default
@@ -370,7 +414,7 @@ class Item(BaseModel):
             if action == "PUT" and new_value == "" and attribute_name in key_attributes:
                 raise EmptyKeyAttributeException
 
-    def update_with_attribute_updates(self, attribute_updates: Dict[str, Any]) -> None:
+    def update_with_attribute_updates(self, attribute_updates: dict[str, Any]) -> None:
         for attribute_name, update_action in attribute_updates.items():
             # Use default Action value, if no explicit Action is passed.
             # Default value is 'Put', according to
@@ -383,32 +427,32 @@ class Item(BaseModel):
             new_value = list(update_action["Value"].values())[0]
             if action == "PUT":
                 # TODO deal with other types
-                if set(update_action["Value"].keys()) == set(["SS"]):
+                if set(update_action["Value"].keys()) == {"SS"}:
                     self.attrs[attribute_name] = DynamoType({"SS": new_value})
-                elif set(update_action["Value"].keys()) == set(["NS"]):
+                elif set(update_action["Value"].keys()) == {"NS"}:
                     self.attrs[attribute_name] = DynamoType({"NS": new_value})
                 elif isinstance(new_value, list):
                     self.attrs[attribute_name] = DynamoType({"L": new_value})
                 elif isinstance(new_value, dict):
                     self.attrs[attribute_name] = DynamoType({"M": new_value})
-                elif set(update_action["Value"].keys()) == set(["N"]):
+                elif set(update_action["Value"].keys()) == {"N"}:
                     self.attrs[attribute_name] = DynamoType({"N": new_value})
-                elif set(update_action["Value"].keys()) == set(["NULL"]):
+                elif set(update_action["Value"].keys()) == {"NULL"}:
                     if attribute_name in self.attrs:
                         del self.attrs[attribute_name]
                 else:
                     self.attrs[attribute_name] = DynamoType({"S": new_value})
             elif action == "ADD":
-                if set(update_action["Value"].keys()) == set(["N"]):
+                if set(update_action["Value"].keys()) == {"N"}:
                     existing = self.attrs.get(attribute_name, DynamoType({"N": "0"}))
                     self.attrs[attribute_name] = DynamoType(
                         {"N": str(Decimal(existing.value) + Decimal(new_value))}
                     )
-                elif set(update_action["Value"].keys()) == set(["SS"]):
+                elif set(update_action["Value"].keys()) == {"SS"}:
                     existing = self.attrs.get(attribute_name, DynamoType({"SS": {}}))
                     new_set = set(existing.value).union(set(new_value))
                     self.attrs[attribute_name] = DynamoType({"SS": list(new_set)})
-                elif set(update_action["Value"].keys()) == set(["NS"]):
+                elif set(update_action["Value"].keys()) == {"NS"}:
                     existing = self.attrs.get(attribute_name, DynamoType({"NS": {}}))
                     new_set = set(existing.value).union(set(new_value))
                     self.attrs[attribute_name] = DynamoType({"NS": list(new_set)})
@@ -419,32 +463,34 @@ class Item(BaseModel):
                 else:
                     # TODO: implement other data types
                     raise NotImplementedError(
-                        "ADD not supported for %s"
-                        % ", ".join(update_action["Value"].keys())
+                        "ADD not supported for {}".format(
+                            ", ".join(update_action["Value"].keys())
+                        )
                     )
             elif action == "DELETE":
-                if set(update_action["Value"].keys()) == set(["SS"]):
+                if set(update_action["Value"].keys()) == {"SS"}:
                     existing = self.attrs.get(attribute_name, DynamoType({"SS": {}}))
                     new_set = set(existing.value).difference(set(new_value))
                     self.attrs[attribute_name] = DynamoType({"SS": list(new_set)})
-                elif set(update_action["Value"].keys()) == set(["NS"]):
+                elif set(update_action["Value"].keys()) == {"NS"}:
                     existing = self.attrs.get(attribute_name, DynamoType({"NS": {}}))
                     new_set = set(existing.value).difference(set(new_value))
                     self.attrs[attribute_name] = DynamoType({"NS": list(new_set)})
                 else:
                     raise NotImplementedError(
-                        "ADD not supported for %s"
-                        % ", ".join(update_action["Value"].keys())
+                        "ADD not supported for {}".format(
+                            ", ".join(update_action["Value"].keys())
+                        )
                     )
             else:
                 raise NotImplementedError(
                     f"{action} action not support for update_with_attribute_updates"
                 )
 
-    def project(self, projection_expressions: List[List[str]]) -> "Item":
+    def project(self, projection_expressions: list[list[str]]) -> "Item":
         # Returns a new Item with only the dictionary-keys that match the provided projection_expression
         # Will return an empty Item if the expression does not match anything
-        result: Dict[str, Any] = dict()
+        result: dict[str, Any] = {}
         for expr in projection_expressions:
             x = find_nested_key(expr, self.to_regular_json())
             merge_dicts(result, x)
@@ -458,7 +504,7 @@ class Item(BaseModel):
         )
 
     def is_within_segment(
-        self, segments: Union[Tuple[None, None], Tuple[int, int]]
+        self, segments: Union[tuple[None, None], tuple[int, int]]
     ) -> bool:
         """
         Segments can be either (x, y) or (None, None)
