@@ -310,12 +310,24 @@ class Instance(TaggedEC2Resource, BotoInstance, CloudFormationModel):
     def get_block_device_mapping(self) -> ItemsView[str, Any]:  # type: ignore[misc]
         return self.block_device_mapping.items()
 
+    @staticmethod
+    def get_block_device_status(volume_status: str) -> str:
+        """Convert volume status to attachment status"""
+        if volume_status == "in-use":
+            return "attached"
+        elif volume_status == "available":
+            return "detached"
+
+        return volume_status
+
     @property
     def block_device_mappings(self) -> list[dict[str, Any]]:
-        return [
-            {"DeviceName": device_name, "Ebs": block}
-            for device_name, block in self.get_block_device_mapping
-        ]
+        result = []
+        for device_name, block in self.get_block_device_mapping:
+            block_copy = copy.copy(block)
+            block_copy.status = self.get_block_device_status(block.status)
+            result.append({"DeviceName": device_name, "Ebs": block_copy})
+        return result
 
     @property
     def network_interfaces(self) -> list[NetworkInterface]:
@@ -1069,6 +1081,11 @@ class InstanceBackend:
             reservations = filter_reservations(reservations, filters)
         return reservations
 
+    def get_instance_uefi_data(self, instance_id: str) -> bytes:
+        # Just a stub for now, doesn't return any actual data.
+        _ = self.get_instance(instance_id)
+        return b""
+
     def _get_template_from_args(
         self, launch_template_arg: dict[str, Any]
     ) -> LaunchTemplateVersion:
