@@ -1,8 +1,6 @@
 """Handles Firehose API requests, invokes method and returns response."""
 
-import json
-
-from moto.core.responses import BaseResponse
+from moto.core.responses import ActionResult, BaseResponse, EmptyResult
 
 from .models import FirehoseBackend, firehose_backends
 
@@ -18,7 +16,7 @@ class FirehoseResponse(BaseResponse):
         """Return backend instance specific to this region."""
         return firehose_backends[self.current_account][self.region]
 
-    def create_delivery_stream(self) -> str:
+    def create_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to CreateDeliveryStream request."""
         delivery_stream_arn = self.firehose_backend.create_delivery_stream(
             self.region,
@@ -35,69 +33,69 @@ class FirehoseResponse(BaseResponse):
             self._get_param("SnowflakeDestinationConfiguration"),
             self._get_param("Tags"),
         )
-        return json.dumps({"DeliveryStreamARN": delivery_stream_arn})
+        return ActionResult({"DeliveryStreamARN": delivery_stream_arn})
 
-    def delete_delivery_stream(self) -> str:
+    def delete_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to DeleteDeliveryStream request."""
         self.firehose_backend.delete_delivery_stream(
             self._get_param("DeliveryStreamName")
         )
-        return json.dumps({})
+        return EmptyResult()
 
-    def describe_delivery_stream(self) -> str:
+    def describe_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to DescribeDeliveryStream request."""
         result = self.firehose_backend.describe_delivery_stream(
             self._get_param("DeliveryStreamName")
         )
-        return json.dumps(result)
+        return ActionResult(result)
 
-    def list_delivery_streams(self) -> str:
+    def list_delivery_streams(self) -> ActionResult:
         """Prepare arguments and respond to ListDeliveryStreams request."""
         stream_list = self.firehose_backend.list_delivery_streams(
             self._get_param("Limit"),
             self._get_param("DeliveryStreamType"),
             self._get_param("ExclusiveStartDeliveryStreamName"),
         )
-        return json.dumps(stream_list)
+        return ActionResult(stream_list)
 
-    def list_tags_for_delivery_stream(self) -> str:
+    def list_tags_for_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to ListTagsForDeliveryStream()."""
         result = self.firehose_backend.list_tags_for_delivery_stream(
             self._get_param("DeliveryStreamName"),
             self._get_param("ExclusiveStartTagKey"),
             self._get_param("Limit"),
         )
-        return json.dumps(result)
+        return ActionResult(result)
 
-    def put_record(self) -> str:
+    def put_record(self) -> ActionResult:
         """Prepare arguments and response to PutRecord()."""
         result = self.firehose_backend.put_record(
             self._get_param("DeliveryStreamName"), self._get_param("Record")
         )
-        return json.dumps(result)
+        return ActionResult(result)
 
-    def put_record_batch(self) -> str:
+    def put_record_batch(self) -> ActionResult:
         """Prepare arguments and response to PutRecordBatch()."""
         result = self.firehose_backend.put_record_batch(
             self._get_param("DeliveryStreamName"), self._get_param("Records")
         )
-        return json.dumps(result)
+        return ActionResult(result)
 
-    def tag_delivery_stream(self) -> str:
+    def tag_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to TagDeliveryStream request."""
         self.firehose_backend.tag_delivery_stream(
             self._get_param("DeliveryStreamName"), self._get_param("Tags")
         )
-        return json.dumps({})
+        return EmptyResult()
 
-    def untag_delivery_stream(self) -> str:
+    def untag_delivery_stream(self) -> ActionResult:
         """Prepare arguments and respond to UntagDeliveryStream()."""
         self.firehose_backend.untag_delivery_stream(
             self._get_param("DeliveryStreamName"), self._get_param("TagKeys")
         )
-        return json.dumps({})
+        return EmptyResult()
 
-    def update_destination(self) -> str:
+    def update_destination(self) -> ActionResult:
         """Prepare arguments and respond to UpdateDestination()."""
         self.firehose_backend.update_destination(
             self._get_param("DeliveryStreamName"),
@@ -112,9 +110,9 @@ class FirehoseResponse(BaseResponse):
             self._get_param("HttpEndpointDestinationUpdate"),
             self._get_param("SnowflakeDestinationConfiguration"),
         )
-        return json.dumps({})
+        return EmptyResult()
 
-    def start_delivery_stream_encryption(self) -> str:
+    def start_delivery_stream_encryption(self) -> ActionResult:
         stream_name = self._get_param("DeliveryStreamName")
         encryption_config = self._get_param(
             "DeliveryStreamEncryptionConfigurationInput"
@@ -122,9 +120,9 @@ class FirehoseResponse(BaseResponse):
         self.firehose_backend.start_delivery_stream_encryption(
             stream_name, encryption_config
         )
-        return "{}"
+        return EmptyResult()
 
-    def stop_delivery_stream_encryption(self) -> str:
+    def stop_delivery_stream_encryption(self) -> ActionResult:
         stream_name = self._get_param("DeliveryStreamName")
         self.firehose_backend.stop_delivery_stream_encryption(stream_name)
-        return "{}"
+        return EmptyResult()
