@@ -9,6 +9,8 @@ class ScheduleExists(JsonRESTError):
 
 
 class ScheduleNotFound(JsonRESTError):
+    code = 404
+
     def __init__(self, name: str) -> None:
         super().__init__(
             "ResourceNotFoundException", f"Schedule {name} does not exist."
@@ -16,8 +18,12 @@ class ScheduleNotFound(JsonRESTError):
 
 
 class ScheduleGroupNotFound(JsonRESTError):
-    def __init__(self) -> None:
-        super().__init__("ResourceNotFoundException", "ScheduleGroup not found")
+    code = 404
+
+    def __init__(self, name: str) -> None:
+        super().__init__(
+            "ResourceNotFoundException", f"Schedule group {name} does not exist."
+        )
 
 
 class ValidationException(JsonRESTError):
