@@ -4,8 +4,9 @@ import json
 import re
 import time
 from collections import defaultdict
+from collections.abc import Iterator
 from dataclasses import dataclass
-from typing import Any, DefaultDict, Dict, Iterator, List, Optional, Tuple
+from typing import Any, Optional
 
 import yaml
 
@@ -48,7 +49,7 @@ from .exceptions import (
 from .utils import convert_to_params, parameter_arn
 
 
-class ParameterDict(DefaultDict[str, List["Parameter"]]):
+class ParameterDict(defaultdict[str, list["Parameter"]]):
     def __init__(self, account_id: str, region_name: str):
         # each value is a list of all the versions for a parameter
         # to get the current value, grab the last item of the list
@@ -133,7 +134,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
                 )
             )
 
-    def _get_secretsmanager_parameter(self, secret_name: str) -> List["Parameter"]:
+    def _get_secretsmanager_parameter(self, secret_name: str) -> list["Parameter"]:
         secrets_backend = secretsmanager_backends[self.account_id][self.region_name]
         secret = secrets_backend.describe_secret(secret_name).to_dict()
         version_id_to_stage = secret["VersionIdsToStages"]
@@ -167,7 +168,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
             for val in values
         ]
 
-    def __getitem__(self, item: str) -> List["Parameter"]:
+    def __getitem__(self, item: str) -> list["Parameter"]:
         if item.startswith("/aws/reference/secretsmanager/"):
             return self._get_secretsmanager_parameter("/".join(item.split("/")[4:]))
         self._check_loading_status(item)
@@ -207,6 +208,7 @@ class ParameterDict(DefaultDict[str, List["Parameter"]]):
 
 PARAMETER_VERSION_LIMIT = 100
 PARAMETER_HISTORY_MAX_RESULTS = 50
+PARAMETER_BY_PATH_MAX_RESULTS = 10
 
 
 class Parameter(CloudFormationModel):
@@ -222,7 +224,7 @@ class Parameter(CloudFormationModel):
         last_modified_date: float,
         version: int,
         data_type: str,
-        labels: Optional[List[str]] = None,
+        labels: Optional[list[str]] = None,
         source_result: Optional[str] = None,
         tier: Optional[str] = None,
         policies: Optional[str] = None,
@@ -263,8 +265,8 @@ class Parameter(CloudFormationModel):
 
     def response_object(
         self, decrypt: bool = False, region: Optional[str] = None
-    ) -> Dict[str, Any]:
-        r: Dict[str, Any] = {
+    ) -> dict[str, Any]:
+        r: dict[str, Any] = {
             "Name": self.name,
             "Type": self.parameter_type,
             "Value": self.decrypt(self.value) if decrypt else self.value,
@@ -292,8 +294,8 @@ class Parameter(CloudFormationModel):
 
     def describe_response_object(
         self, decrypt: bool = False, include_labels: bool = False
-    ) -> Dict[str, Any]:
-        r: Dict[str, Any] = self.response_object(decrypt)
+    ) -> dict[str, Any]:
+        r: dict[str, Any] = self.response_object(decrypt)
         r["LastModifiedDate"] = round(self.last_modified_date, 3)
         r["LastModifiedUser"] = "N/A"
 
@@ -388,8 +390,8 @@ MAX_TIMEOUT_SECONDS = 3600
 
 
 def generate_ssm_doc_param_list(
-    parameters: Dict[str, Any],
-) -> Optional[List[Dict[str, Any]]]:
+    parameters: dict[str, Any],
+) -> Optional[list[dict[str, Any]]]:
     if not parameters:
         return None
     param_list = []
@@ -430,7 +432,7 @@ class Documents(BaseModel):
         self.versions = {version: ssm_document}
         self.default_version = version
         self.latest_version = version
-        self.permissions: Dict[
+        self.permissions: dict[
             str, AccountPermission
         ] = {}  # {AccountID: AccountPermission }
 
@@ -472,7 +474,7 @@ class Documents(BaseModel):
         strict: bool = True,
     ) -> "Document":
         if document_version == "$LATEST":
-            ssm_document: Optional["Document"] = self.get_latest_version()
+            ssm_document: Optional[Document] = self.get_latest_version()
         elif version_name and document_version:
             ssm_document = self.find_by_version_and_version_name(
                 document_version, version_name
@@ -520,10 +522,10 @@ class Documents(BaseModel):
         self,
         document_version: Optional[str] = None,
         version_name: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
-    ) -> Dict[str, Any]:
+        tags: Optional[list[dict[str, str]]] = None,
+    ) -> dict[str, Any]:
         document = self.find(document_version, version_name)
-        base: Dict[str, Any] = {
+        base: dict[str, Any] = {
             "Hash": document.hash,
             "HashType": "Sha256",
             "Name": document.name,
@@ -550,7 +552,7 @@ class Documents(BaseModel):
         return base
 
     def modify_permissions(
-        self, accounts_to_add: List[str], accounts_to_remove: List[str], version: str
+        self, accounts_to_add: list[str], accounts_to_remove: list[str], version: str
     ) -> None:
         version = version or "$DEFAULT"
         if accounts_to_add:
@@ -574,7 +576,7 @@ class Documents(BaseModel):
                 for account_id in accounts_to_remove:
                     self.permissions.pop(account_id, None)
 
-    def describe_permissions(self) -> Dict[str, Any]:
+    def describe_permissions(self) -> dict[str, Any]:
         permissions_ordered_by_date = sorted(
             self.permissions.values(), key=lambda p: p.created_at
         )
@@ -600,8 +602,8 @@ class Document(BaseModel):
         content: str,
         document_type: str,
         document_format: str,
-        requires: List[Dict[str, str]],
-        attachments: List[Dict[str, Any]],
+        requires: list[dict[str, str]],
+        attachments: list[dict[str, Any]],
         target_type: str,
         document_version: str = "1",
     ):
@@ -662,9 +664,9 @@ class Document(BaseModel):
         return hashlib.sha256(self.content.encode("utf-8")).hexdigest()
 
     def list_describe(
-        self, tags: Optional[List[Dict[str, str]]] = None
-    ) -> Dict[str, Any]:
-        base: Dict[str, Any] = {
+        self, tags: Optional[list[dict[str, str]]] = None
+    ) -> dict[str, Any]:
+        base: dict[str, Any] = {
             "Name": self.name,
             "Owner": self.owner,
             "DocumentVersion": self.document_version,
@@ -693,16 +695,16 @@ class Command(BaseModel):
         comment: str = "",
         document_name: Optional[str] = "",
         timeout_seconds: Optional[int] = MAX_TIMEOUT_SECONDS,
-        instance_ids: Optional[List[str]] = None,
+        instance_ids: Optional[list[str]] = None,
         max_concurrency: str = "",
         max_errors: str = "",
-        notification_config: Optional[Dict[str, Any]] = None,
+        notification_config: Optional[dict[str, Any]] = None,
         output_s3_bucket_name: str = "",
         output_s3_key_prefix: str = "",
         output_s3_region: str = "",
-        parameters: Optional[Dict[str, List[str]]] = None,
+        parameters: Optional[dict[str, list[str]]] = None,
         service_role_arn: str = "",
-        targets: Optional[List[Dict[str, Any]]] = None,
+        targets: Optional[list[dict[str, Any]]] = None,
         backend_region: str = "us-east-1",
     ):
         if instance_ids is None:
@@ -765,7 +767,7 @@ class Command(BaseModel):
                 self.invocation_response(instance_id, "aws:runShellScript")
             )
 
-    def _get_instance_ids_from_targets(self) -> List[str]:
+    def _get_instance_ids_from_targets(self) -> list[str]:
         target_instance_ids = []
         ec2_backend = ec2_backends[self.account_id][self.backend_region]
         ec2_filters = {target["Key"]: target["Values"] for target in self.targets}
@@ -775,7 +777,7 @@ class Command(BaseModel):
                 target_instance_ids.append(instance.id)
         return target_instance_ids
 
-    def response_object(self) -> Dict[str, Any]:
+    def response_object(self) -> dict[str, Any]:
         return {
             "CommandId": self.command_id,
             "Comment": self.comment,
@@ -801,7 +803,7 @@ class Command(BaseModel):
             "TimeoutSeconds": self.timeout_seconds,
         }
 
-    def invocation_response(self, instance_id: str, plugin_name: str) -> Dict[str, Any]:
+    def invocation_response(self, instance_id: str, plugin_name: str) -> dict[str, Any]:
         # Calculate elapsed time from requested time and now. Use a hardcoded
         # elapsed time since there is no easy way to convert a timedelta to
         # an ISO 8601 duration string.
@@ -828,7 +830,7 @@ class Command(BaseModel):
 
     def get_invocation(
         self, instance_id: str, plugin_name: Optional[str]
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         invocation = next(
             (
                 invocation
@@ -897,7 +899,7 @@ def _validate_document_info(
 
 
 def _document_filter_equal_comparator(
-    keyed_value: str, _filter: Dict[str, Any]
+    keyed_value: str, _filter: dict[str, Any]
 ) -> bool:
     for v in _filter["Values"]:
         if keyed_value == v:
@@ -906,7 +908,7 @@ def _document_filter_equal_comparator(
 
 
 def _document_filter_list_includes_comparator(
-    keyed_value_list: List[str], _filter: Dict[str, Any]
+    keyed_value_list: list[str], _filter: dict[str, Any]
 ) -> bool:
     for v in _filter["Values"]:
         if v in keyed_value_list:
@@ -915,7 +917,7 @@ def _document_filter_list_includes_comparator(
 
 
 def _document_filter_match(
-    account_id: str, filters: List[Dict[str, Any]], ssm_doc: Document
+    account_id: str, filters: list[dict[str, Any]], ssm_doc: Document
 ) -> bool:
     for _filter in filters:
         if _filter["Key"] == "Name" and not _document_filter_equal_comparator(
@@ -973,7 +975,7 @@ class FakeMaintenanceWindowTarget:
         self,
         window_id: str,
         resource_type: str,
-        targets: List[Dict[str, Any]],
+        targets: list[dict[str, Any]],
         owner_information: Optional[str],
         name: Optional[str],
         description: Optional[str],
@@ -986,7 +988,7 @@ class FakeMaintenanceWindowTarget:
         self.description = description
         self.owner_information = owner_information
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "WindowId": self.window_id,
             "WindowTargetId": self.window_target_id,
@@ -1006,20 +1008,20 @@ class FakeMaintenanceWindowTask:
     def __init__(
         self,
         window_id: str,
-        targets: Optional[List[Dict[str, Any]]],
+        targets: Optional[list[dict[str, Any]]],
         task_arn: str,
         service_role_arn: Optional[str],
         task_type: str,
-        task_parameters: Optional[Dict[str, Any]],
-        task_invocation_parameters: Optional[Dict[str, Any]],
+        task_parameters: Optional[dict[str, Any]],
+        task_invocation_parameters: Optional[dict[str, Any]],
         priority: Optional[int],
         max_concurrency: Optional[str],
         max_errors: Optional[str],
-        logging_info: Optional[Dict[str, Any]],
+        logging_info: Optional[dict[str, Any]],
         name: Optional[str],
         description: Optional[str],
         cutoff_behavior: Optional[str],
-        alarm_configurations: Optional[Dict[str, Any]],
+        alarm_configurations: Optional[dict[str, Any]],
     ):
         self.window_task_id = FakeMaintenanceWindowTask.generate_id()
         self.window_id = window_id
@@ -1038,7 +1040,7 @@ class FakeMaintenanceWindowTask:
         self.cutoff_behavior = cutoff_behavior
         self.alarm_configurations = alarm_configurations
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "WindowId": self.window_id,
             "WindowTaskId": self.window_task_id,
@@ -1062,7 +1064,7 @@ class FakeMaintenanceWindowTask:
 
 
 def _maintenance_window_target_filter_match(
-    filters: Optional[List[Dict[str, Any]]], target: FakeMaintenanceWindowTarget
+    filters: Optional[list[dict[str, Any]]], target: FakeMaintenanceWindowTarget
 ) -> bool:
     if not filters and target:
         return True
@@ -1070,7 +1072,7 @@ def _maintenance_window_target_filter_match(
 
 
 def _maintenance_window_task_filter_match(
-    filters: Optional[List[Dict[str, Any]]], task: FakeMaintenanceWindowTask
+    filters: Optional[list[dict[str, Any]]], task: FakeMaintenanceWindowTask
 ) -> bool:
     if not filters and task:
         return True
@@ -1100,10 +1102,10 @@ class FakeMaintenanceWindow:
         self.schedule_offset = schedule_offset
         self.start_date = start_date
         self.end_date = end_date
-        self.targets: Dict[str, FakeMaintenanceWindowTarget] = {}
-        self.tasks: Dict[str, FakeMaintenanceWindowTask] = {}
+        self.targets: dict[str, FakeMaintenanceWindowTarget] = {}
+        self.tasks: dict[str, FakeMaintenanceWindowTask] = {}
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "WindowId": self.id,
             "Name": self.name,
@@ -1129,15 +1131,15 @@ class FakePatchBaseline:
         self,
         name: str,
         operating_system: str,
-        global_filters: Optional[Dict[str, Any]],
-        approval_rules: Optional[Dict[str, Any]],
-        approved_patches: Optional[List[str]],
+        global_filters: Optional[dict[str, Any]],
+        approval_rules: Optional[dict[str, Any]],
+        approved_patches: Optional[list[str]],
         approved_patches_compliance_level: Optional[str],
         approved_patches_enable_non_security: Optional[bool],
-        rejected_patches: Optional[List[str]],
+        rejected_patches: Optional[list[str]],
         rejected_patches_action: Optional[str],
         description: Optional[str],
-        sources: Optional[List[Dict[str, Any]]],
+        sources: Optional[list[dict[str, Any]]],
     ):
         self.id = FakePatchBaseline.generate_id()
         self.operating_system = operating_system
@@ -1153,7 +1155,7 @@ class FakePatchBaseline:
         self.sources = sources
         self.default_baseline = False
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "BaselineId": self.id,
             "OperatingSystem": self.operating_system,
@@ -1209,25 +1211,26 @@ class SimpleSystemManagerBackend(BaseBackend):
         super().__init__(region_name, account_id)
         self._parameters = ParameterDict(account_id, region_name)
 
-        self._resource_tags: DefaultDict[str, DefaultDict[str, Dict[str, str]]] = (
+        self._resource_tags: defaultdict[str, defaultdict[str, dict[str, str]]] = (
             defaultdict(lambda: defaultdict(dict))
         )
-        self._commands: List[Command] = []
-        self._errors: List[str] = []
-        self._documents: Dict[str, Documents] = {}
+        self._commands: list[Command] = []
+        self._errors: list[str] = []
+        self._documents: dict[str, Documents] = {}
 
-        self.windows: Dict[str, FakeMaintenanceWindow] = dict()
-        self.baselines: Dict[str, FakePatchBaseline] = dict()
-        self.patch_groups: Dict[str, FakePatchGroup] = dict()
+        self.windows: dict[str, FakeMaintenanceWindow] = {}
+        self.baselines: dict[str, FakePatchBaseline] = {}
+        self.patch_groups: dict[str, FakePatchGroup] = {}
         self.ssm_prefix = (
             f"arn:{self.partition}:ssm:{self.region_name}:{self.account_id}:parameter"
         )
+        self.default_parameter_tier = "Standard"
 
     def _generate_document_information(
         self, ssm_document: Document, document_format: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         content = self._get_document_content(document_format, ssm_document)
-        base: Dict[str, Any] = {
+        base: dict[str, Any] = {
             "Name": ssm_document.name,
             "DocumentVersion": ssm_document.document_version,
             "Status": ssm_document.status,
@@ -1263,7 +1266,7 @@ class SimpleSystemManagerBackend(BaseBackend):
             raise InvalidDocument("The specified document does not exist.")
         return documents
 
-    def _get_documents_tags(self, name: str) -> List[Dict[str, str]]:
+    def _get_documents_tags(self, name: str) -> list[dict[str, str]]:
         docs_tags = self._resource_tags.get("Document")
         if docs_tags:
             document_tags = docs_tags.get(name, {})
@@ -1275,15 +1278,15 @@ class SimpleSystemManagerBackend(BaseBackend):
     def create_document(
         self,
         content: str,
-        requires: List[Dict[str, str]],
-        attachments: List[Dict[str, Any]],
+        requires: list[dict[str, str]],
+        attachments: list[dict[str, Any]],
         name: str,
         version_name: str,
         document_type: str,
         document_format: str,
         target_type: str,
-        tags: List[Dict[str, str]],
-    ) -> Dict[str, Any]:
+        tags: list[dict[str, str]],
+    ) -> dict[str, Any]:
         ssm_document = Document(
             account_id=self.account_id,
             name=name,
@@ -1371,7 +1374,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def get_document(
         self, name: str, document_version: str, version_name: str, document_format: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         documents = self._get_documents(name)
         ssm_document = documents.find(document_version, version_name)
 
@@ -1384,11 +1387,11 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def update_document_default_version(
         self, name: str, document_version: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         documents = self._get_documents(name)
         ssm_document = documents.update_default_version(document_version)
 
-        result: Dict[str, Any] = {
+        result: dict[str, Any] = {
             "Name": ssm_document.name,
             "DefaultVersion": document_version,
         }
@@ -1401,13 +1404,13 @@ class SimpleSystemManagerBackend(BaseBackend):
     def update_document(
         self,
         content: str,
-        attachments: List[Dict[str, Any]],
+        attachments: list[dict[str, Any]],
         name: str,
         version_name: str,
         document_version: str,
         document_format: str,
         target_type: str,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         _validate_document_info(
             content=content,
             name=name,
@@ -1464,7 +1467,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def describe_document(
         self, name: str, document_version: str, version_name: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         documents = self._get_documents(name)
         tags = self._get_documents_tags(name)
         return documents.describe(document_version, version_name, tags=tags)
@@ -1472,17 +1475,17 @@ class SimpleSystemManagerBackend(BaseBackend):
     def list_documents(
         self,
         document_filter_list: Any,
-        filters: List[Dict[str, Any]],
+        filters: list[dict[str, Any]],
         max_results: int = 10,
         token: str = "0",
-    ) -> Tuple[List[Dict[str, Any]], str]:
+    ) -> tuple[list[dict[str, Any]], str]:
         if document_filter_list:
             raise ValidationException(
                 "DocumentFilterList is deprecated. Instead use Filters."
             )
 
         next_token = int(token or "0")
-        results: List[Dict[str, Any]] = []
+        results: list[dict[str, Any]] = []
         dummy_token_tracker = 0
         # Sort to maintain next token adjacency
         for _, documents in sorted(self._documents.items()):
@@ -1508,7 +1511,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         # If we've fallen out of the loop, there are no more documents. No next token.
         return results, ""
 
-    def describe_document_permission(self, name: str) -> Dict[str, Any]:
+    def describe_document_permission(self, name: str) -> dict[str, Any]:
         """
         Parameters max_results, permission_type, and next_token not yet implemented
         """
@@ -1518,8 +1521,8 @@ class SimpleSystemManagerBackend(BaseBackend):
     def modify_document_permission(
         self,
         name: str,
-        account_ids_to_add: List[str],
-        account_ids_to_remove: List[str],
+        account_ids_to_add: list[str],
+        account_ids_to_remove: list[str],
         shared_document_version: str,
         permission_type: str,
     ) -> None:
@@ -1575,7 +1578,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         self._resource_tags.get("Parameter", {}).pop(normalized_parameter_name, None)  # type: ignore
         return self._parameters.pop(normalized_parameter_name, None)  # type: ignore
 
-    def delete_parameters(self, names: List[str]) -> List[str]:
+    def delete_parameters(self, names: list[str]) -> list[str]:
         result = []
         for name in names:
             try:
@@ -1590,8 +1593,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         return result
 
     def describe_parameters(
-        self, filters: List[Dict[str, Any]], parameter_filters: List[Dict[str, Any]]
-    ) -> List[Parameter]:
+        self, filters: list[dict[str, Any]], parameter_filters: list[dict[str, Any]]
+    ) -> list[Parameter]:
         if filters and parameter_filters:
             raise ValidationException(
                 "You can use either Filters or ParameterFilters in a single request."
@@ -1631,7 +1634,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         return result
 
     def _validate_parameter_filters(
-        self, parameter_filters: Optional[List[Dict[str, Any]]], by_path: bool
+        self, parameter_filters: Optional[list[dict[str, Any]]], by_path: bool
     ) -> None:
         for index, filter_obj in enumerate(parameter_filters or []):
             key = filter_obj["Key"]
@@ -1792,7 +1795,7 @@ class SimpleSystemManagerBackend(BaseBackend):
                 f"{count} validation error{plural} detected: {errors}"
             )
 
-    def get_parameters(self, names: List[str]) -> Dict[str, Parameter]:
+    def get_parameters(self, names: list[str]) -> dict[str, Parameter]:
         result = {}
 
         if len(names) > 10:
@@ -1817,15 +1820,21 @@ class SimpleSystemManagerBackend(BaseBackend):
         self,
         path: str,
         recursive: bool,
-        filters: Optional[List[Dict[str, Any]]] = None,
+        filters: Optional[list[dict[str, Any]]] = None,
         next_token: Optional[str] = None,
         max_results: int = 10,
-    ) -> Tuple[List[Parameter], Optional[str]]:
+    ) -> tuple[list[Parameter], Optional[str]]:
         """Implement the get-parameters-by-path-API in the backend."""
+        if max_results > PARAMETER_BY_PATH_MAX_RESULTS:
+            raise ValidationException(
+                "1 validation error detected: "
+                f"Value {max_results} at 'maxResults' failed to satisfy constraint: "
+                f"Member must have value less than or equal to {PARAMETER_BY_PATH_MAX_RESULTS}"
+            )
 
         self._validate_parameter_filters(filters, by_path=True)
 
-        result: List[Parameter] = []
+        result: list[Parameter] = []
         # path could be with or without a trailing /. we handle this
         # difference here.
         path = path.rstrip("/") + "/"
@@ -1839,10 +1848,10 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def _get_values_nexttoken(
         self,
-        values_list: List[Parameter],
+        values_list: list[Parameter],
         max_results: int,
         token: Optional[str] = None,
-    ) -> Tuple[List[Parameter], Optional[str]]:
+    ) -> tuple[list[Parameter], Optional[str]]:
         next_token = int(token or "0")
         max_results = int(max_results)
         values = values_list[next_token : next_token + max_results]
@@ -1853,7 +1862,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def get_parameter_history(
         self, name: str, next_token: Optional[str], max_results: int = 50
-    ) -> Tuple[Optional[List[Parameter]], Optional[str]]:
+    ) -> tuple[Optional[list[Parameter]], Optional[str]]:
         if max_results > PARAMETER_HISTORY_MAX_RESULTS:
             raise ValidationException(
                 "1 validation error detected: "
@@ -1868,8 +1877,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         return None, None
 
     def _get_history_nexttoken(
-        self, history: List[Parameter], token: Optional[str], max_results: int
-    ) -> Tuple[List[Parameter], Optional[str]]:
+        self, history: list[Parameter], token: Optional[str], max_results: int
+    ) -> tuple[list[Parameter], Optional[str]]:
         next_token = int(token or "0")
         max_results = int(max_results)
         history_to_return = history[next_token : next_token + max_results]
@@ -1882,7 +1891,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         return history_to_return, None
 
     def _match_filters(
-        self, parameter: Parameter, filters: Optional[List[Dict[str, Any]]] = None
+        self, parameter: Parameter, filters: Optional[list[dict[str, Any]]] = None
     ) -> bool:
         """Return True if the given parameter matches all the filters"""
         parameter_tags = self.list_tags_for_resource("Parameter", parameter.name)
@@ -1990,9 +1999,8 @@ class SimpleSystemManagerBackend(BaseBackend):
                         return result[-1]
                     elif len(parameters) > 0:
                         raise ParameterVersionNotFound(
-                            "Systems Manager could not find version %s of %s. "
+                            f"Systems Manager could not find version {version_or_label} of {name_prefix}. "
                             "Verify the version and try again."
-                            % (version_or_label, name_prefix)
                         )
                 result = list(
                     filter(lambda x: version_or_label in x.labels, parameters)
@@ -2003,8 +2011,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         return None
 
     def label_parameter_version(
-        self, name: str, version: int, labels: List[str]
-    ) -> Tuple[List[str], int]:
+        self, name: str, version: int, labels: list[str]
+    ) -> tuple[list[str], int]:
         previous_parameter_versions = self._parameters[name]
         if not previous_parameter_versions:
             raise ParameterNotFound(f"Parameter {name} not found.")
@@ -2040,10 +2048,9 @@ class SimpleSystemManagerBackend(BaseBackend):
             if len(label) > 100:
                 raise ValidationException(
                     "1 validation error detected: "
-                    "Value '[%s]' at 'labels' failed to satisfy constraint: "
+                    f"Value '[{label}]' at 'labels' failed to satisfy constraint: "
                     "Member must satisfy constraint: "
                     "[Member must have length less than or equal to 100, Member must have length greater than or equal to 1]"
-                    % label
                 )
                 continue
             if label not in found_parameter.labels:
@@ -2062,6 +2069,44 @@ class SimpleSystemManagerBackend(BaseBackend):
                         parameter.labels.remove(label)
         return (invalid_labels, version)
 
+    def unlabel_parameter_version(
+        self, name: str, version: int, labels: list[str]
+    ) -> tuple[list[str], list[str]]:
+        previous_parameter_versions = self._parameters[name]
+        if not previous_parameter_versions:
+            raise ParameterNotFound(f"Parameter {name} not found.")
+
+        if version is None:
+            raise ValidationException(
+                "1 validation error detected: Value 'null' at 'parameterVersion' failed to satisfy constraint: Member must not be null"
+            )
+
+        found_parameter = None
+        for parameter in previous_parameter_versions:
+            if parameter.version == version:
+                found_parameter = parameter
+                break
+
+        if not found_parameter:
+            raise ParameterVersionNotFound(
+                f"Systems Manager could not find version {version} of {name}. Verify the version and try again."
+            )
+
+        removed_labels: list[str] = []
+        invalid_labels: list[str] = []
+
+        if not labels:
+            return removed_labels, invalid_labels
+
+        for label in labels:
+            if label in found_parameter.labels:
+                found_parameter.labels.remove(label)
+                removed_labels.append(label)
+            else:
+                invalid_labels.append(label)
+
+        return removed_labels, invalid_labels
+
     def _check_for_parameter_version_limit_exception(self, name: str) -> None:
         # https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-paramstore-versions.html
         parameter_versions = self._parameters[name]
@@ -2083,7 +2128,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         allowed_pattern: str,
         keyid: str,
         overwrite: bool,
-        tags: List[Dict[str, str]],
+        tags: list[dict[str, str]],
         data_type: str,
         tier: Optional[str],
         policies: Optional[str],
@@ -2177,7 +2222,8 @@ class SimpleSystemManagerBackend(BaseBackend):
             )
             tier = tier if tier is not None else previous_parameter.tier
             policies = policies if policies is not None else previous_parameter.policies
-
+        if tier is None:
+            tier = self.default_parameter_tier
         last_modified_date = time.time()
         new_param = Parameter(
             account_id=self.account_id,
@@ -2202,14 +2248,14 @@ class SimpleSystemManagerBackend(BaseBackend):
         return new_param
 
     def add_tags_to_resource(
-        self, resource_type: str, resource_id: str, tags: Dict[str, str]
+        self, resource_type: str, resource_id: str, tags: dict[str, str]
     ) -> None:
         resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         for key, value in tags.items():
             self._resource_tags[resource_type][resource_id][key] = value
 
     def remove_tags_from_resource(
-        self, resource_type: str, resource_id: str, keys: List[str]
+        self, resource_type: str, resource_id: str, keys: list[str]
     ) -> None:
         resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         tags = self._resource_tags[resource_type][resource_id]
@@ -2219,7 +2265,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def list_tags_for_resource(
         self, resource_type: str, resource_id: str
-    ) -> Dict[str, str]:
+    ) -> dict[str, str]:
         resource_id = self._validate_resource_type_and_id(resource_type, resource_id)
         return self._resource_tags[resource_type][resource_id]
 
@@ -2256,16 +2302,16 @@ class SimpleSystemManagerBackend(BaseBackend):
         comment: str,
         document_name: Optional[str],
         timeout_seconds: int,
-        instance_ids: List[str],
+        instance_ids: list[str],
         max_concurrency: str,
         max_errors: str,
-        notification_config: Optional[Dict[str, Any]],
+        notification_config: Optional[dict[str, Any]],
         output_s3_bucket_name: str,
         output_s3_key_prefix: str,
         output_s3_region: str,
-        parameters: Dict[str, List[str]],
+        parameters: dict[str, list[str]],
         service_role_arn: str,
-        targets: List[Dict[str, Any]],
+        targets: list[dict[str, Any]],
     ) -> Command:
         command = Command(
             account_id=self.account_id,
@@ -2290,7 +2336,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def list_commands(
         self, command_id: Optional[str], instance_id: Optional[str]
-    ) -> List[Command]:
+    ) -> list[Command]:
         """
         Pagination and the Filters-parameter is not yet implemented
         """
@@ -2312,14 +2358,14 @@ class SimpleSystemManagerBackend(BaseBackend):
 
         return command
 
-    def get_commands_by_instance_id(self, instance_id: str) -> List[Command]:
+    def get_commands_by_instance_id(self, instance_id: str) -> list[Command]:
         return [
             command for command in self._commands if instance_id in command.instance_ids
         ]
 
     def get_command_invocation(
         self, command_id: str, instance_id: str, plugin_name: Optional[str]
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         command = self.get_command_by_id(command_id)
         return command.get_invocation(instance_id, plugin_name)
 
@@ -2334,7 +2380,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         schedule_offset: int,
         start_date: str,
         end_date: str,
-        tags: Optional[List[Dict[str, str]]],
+        tags: Optional[list[dict[str, str]]],
     ) -> str:
         """
         Creates a maintenance window. No error handling or input validation has been implemented yet.
@@ -2367,14 +2413,14 @@ class SimpleSystemManagerBackend(BaseBackend):
         return self.windows[window_id]
 
     def describe_maintenance_windows(
-        self, filters: Optional[List[Dict[str, Any]]]
-    ) -> List[FakeMaintenanceWindow]:
+        self, filters: Optional[list[dict[str, Any]]]
+    ) -> list[FakeMaintenanceWindow]:
         """
         Returns all windows. No pagination has been implemented yet. Only filtering for Name is supported.
         The NextExecutionTime-field is not returned.
 
         """
-        res = [window for window in self.windows.values()]
+        res = list(self.windows.values())
         if filters:
             for f in filters:
                 if f["Key"] == "Name":
@@ -2393,16 +2439,16 @@ class SimpleSystemManagerBackend(BaseBackend):
         self,
         name: str,
         operating_system: str,
-        global_filters: Optional[Dict[str, Any]],
-        approval_rules: Optional[Dict[str, Any]],
-        approved_patches: Optional[List[str]],
+        global_filters: Optional[dict[str, Any]],
+        approval_rules: Optional[dict[str, Any]],
+        approved_patches: Optional[list[str]],
         approved_patches_compliance_level: Optional[str],
         approved_patches_enable_non_security: Optional[bool],
-        rejected_patches: Optional[List[str]],
+        rejected_patches: Optional[list[str]],
         rejected_patches_action: Optional[str],
         description: Optional[str],
-        sources: Optional[List[Dict[str, Any]]],
-        tags: Optional[List[Dict[str, str]]],
+        sources: Optional[list[dict[str, Any]]],
+        tags: Optional[list[dict[str, str]]],
     ) -> str:
         """
         Registers a patch baseline. No error handling or input validation has been implemented yet.
@@ -2429,12 +2475,12 @@ class SimpleSystemManagerBackend(BaseBackend):
         return baseline.id
 
     def describe_patch_baselines(
-        self, filters: Optional[List[Dict[str, Any]]]
-    ) -> List[FakePatchBaseline]:
+        self, filters: Optional[list[dict[str, Any]]]
+    ) -> list[FakePatchBaseline]:
         """
         Returns all baselines. No pagination has been implemented yet.
         """
-        baselines = [baseline for baseline in self.baselines.values()]
+        baselines = list(self.baselines.values())
         if filters:
             for f in filters:
                 if f["Key"] == "NAME_PREFIX":
@@ -2455,7 +2501,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         self,
         window_id: str,
         resource_type: str,
-        targets: List[Dict[str, Any]],
+        targets: list[dict[str, Any]],
         owner_information: Optional[str],
         name: Optional[str],
         description: Optional[str],
@@ -2486,8 +2532,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         del window.targets[window_target_id]
 
     def describe_maintenance_window_targets(
-        self, window_id: str, filters: Optional[List[Dict[str, Any]]]
-    ) -> List[FakeMaintenanceWindowTarget]:
+        self, window_id: str, filters: Optional[list[dict[str, Any]]]
+    ) -> list[FakeMaintenanceWindowTarget]:
         """
         Describes all targets for a maintenance window. No error handling has been implemented yet.
         """
@@ -2502,20 +2548,20 @@ class SimpleSystemManagerBackend(BaseBackend):
     def register_task_with_maintenance_window(
         self,
         window_id: str,
-        targets: Optional[List[Dict[str, Any]]],
+        targets: Optional[list[dict[str, Any]]],
         task_arn: str,
         service_role_arn: Optional[str],
         task_type: str,
-        task_parameters: Optional[Dict[str, Any]],
-        task_invocation_parameters: Optional[Dict[str, Any]],
+        task_parameters: Optional[dict[str, Any]],
+        task_invocation_parameters: Optional[dict[str, Any]],
         priority: Optional[int],
         max_concurrency: Optional[str],
         max_errors: Optional[str],
-        logging_info: Optional[Dict[str, Any]],
+        logging_info: Optional[dict[str, Any]],
         name: Optional[str],
         description: Optional[str],
         cutoff_behavior: Optional[str],
-        alarm_configurations: Optional[Dict[str, Any]],
+        alarm_configurations: Optional[dict[str, Any]],
     ) -> str:
         window = self.get_maintenance_window(window_id)
         task = FakeMaintenanceWindowTask(
@@ -2539,8 +2585,8 @@ class SimpleSystemManagerBackend(BaseBackend):
         return task.window_task_id
 
     def describe_maintenance_window_tasks(
-        self, window_id: str, filters: List[Dict[str, Any]]
-    ) -> List[FakeMaintenanceWindowTask]:
+        self, window_id: str, filters: list[dict[str, Any]]
+    ) -> list[FakeMaintenanceWindowTask]:
         window = self.get_maintenance_window(window_id)
         tasks = [
             task
@@ -2557,7 +2603,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def register_patch_baseline_for_patch_group(
         self, baseline_id: str, patch_group: str
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         """register a patch group in ssm backend"""
         if baseline_id not in self.baselines.keys():
             raise DoesNotExistException(baseline_id)
@@ -2574,7 +2620,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def get_patch_baseline_for_patch_group(
         self, patch_group: str, operating_system: str
-    ) -> Tuple[str, str, str]:
+    ) -> tuple[str, str, str]:
         """get baselineid for patch group for operating system"""
         if patch_group not in self.patch_groups.keys():
             fake_patch_group = FakePatchGroup("Fake", self.region_name)
@@ -2585,7 +2631,7 @@ class SimpleSystemManagerBackend(BaseBackend):
 
     def deregister_patch_baseline_for_patch_group(
         self, baseline_id: str, patch_group: str
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         """deregister a patch baseline for os on patch group, set default"""
         if patch_group in self.patch_groups.keys():
             if baseline_id not in self.baselines.keys():
